(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    157015,       4032]
NotebookOptionsPosition[    143086,       3800]
NotebookOutlinePosition[    143534,       3817]
CellTagsIndexPosition[    143491,       3814]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Electron EDM in the complex two-Higgs doublet model", "Subtitle",
 CellChangeTimes->{
  3.8097147551966543`*^9},ExpressionUUID->"ac6ede36-32ed-4a39-ad73-\
590cf73ce3b8"],

Cell[CellGroupData[{

Cell["nick hamer, ucsc", "Item",
 CellChangeTimes->{{3.810063952034017*^9, 
  3.8100639540579944`*^9}},ExpressionUUID->"75a2e040-a9ba-41b2-b6a3-\
699955f534e5"],

Cell["nhamer@ucsc.edu", "Subitem",
 CellChangeTimes->{{3.810063952034017*^9, 
  3.8100640185401974`*^9}},ExpressionUUID->"c41e8437-67a1-4d56-a723-\
791039720dba"],

Cell[TextData[ButtonBox["Based on arxiv.org/pdf/2009.01258.pdf",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://arxiv.org/pdf/2009.01258.pdf"], None},
 ButtonNote->"https://arxiv.org/pdf/2009.01258.pdf"]], "Item",
 CellChangeTimes->{{3.809714677044778*^9, 3.8097146952137775`*^9}, {
  3.810009005855633*^9, 
  3.810009008298613*^9}},ExpressionUUID->"ff648a4c-874f-4f51-98b1-\
4b3b4bce9781"]
}, Open  ]],

Cell[CellGroupData[{

Cell["definitions, common functions", "Subsection",
 CellChangeTimes->{{3.809714729490713*^9, 
  3.809714734827707*^9}},ExpressionUUID->"90f2a486-7f2d-4578-b44f-\
0f4228b2d961"],

Cell[CellGroupData[{

Cell["masses, constants", "Subsubsection",
 CellChangeTimes->{{3.8097215320820274`*^9, 
  3.809721536743002*^9}},ExpressionUUID->"ed8a5825-031b-4e5c-803d-\
c935ac60f1ea"],

Cell[CellGroupData[{

Cell["light fermion masses from PDG", "Item",
 CellChangeTimes->{{3.8097151693256273`*^9, 
  3.809715196416443*^9}},ExpressionUUID->"8cb018c9-3bd9-4cb2-8250-\
78e698f4bcb9"],

Cell["heavy fermion masses at Z pole, eq. (66)", "Item",
 CellChangeTimes->{{3.8097151693256273`*^9, 
  3.8097152048244486`*^9}},ExpressionUUID->"b3c931dd-dd46-4542-a273-\
6422d0c2a00f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"masses", "=", 
   RowBox[{"\[LeftAssociation]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<u\>\"", "\[Rule]", "0.0022"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<d\>\"", "\[Rule]", "0.0047"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<s\>\"", "\[Rule]", "0.093"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "1.2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "2.88"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<t\>\"", "\[Rule]", "163"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<e\>\"", "\[Rule]", "0.000511"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<\[Mu]\>\"", "\[Rule]", "0.10566"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", "1.777"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<W\>\"", "\[Rule]", "80.34"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<Z\>\"", "\[Rule]", "91.19"}], ",", "\[IndentingNewLine]", 
     RowBox[{"\"\<h\>\"", "\[Rule]", "125"}]}], "\[IndentingNewLine]", 
    "\[RightAssociation]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097149324147882`*^9, 3.8097149647907944`*^9}, {
  3.809714999572148*^9, 3.8097150153780317`*^9}, {3.809715372841414*^9, 
  3.8097154102304525`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"5f498747-a4fc-4d75-9809-e24e6d13ccb1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]em", "[", "0", "]"}], "=", 
   RowBox[{"1", "/", "137"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]em", "[", "\"\<Z\>\"", "]"}], "=", 
   RowBox[{"1", "/", "129"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8013330364168363`*^9, 3.801333069706184*^9}, {
   3.801333442623082*^9, 3.801333455776955*^9}, 3.8013343772421236`*^9, 
   3.801343748901089*^9, {3.801509459270452*^9, 3.801509465574605*^9}, {
   3.8015104028640594`*^9, 3.80151042245111*^9}, {3.8015106720623426`*^9, 
   3.8015106753421707`*^9}, {3.8015126273856497`*^9, 3.801512649517327*^9}, 
   3.8015128743364363`*^9, 3.805644450764838*^9, {3.8097157012718277`*^9, 
   3.8097157030518303`*^9}, {3.8097158103378277`*^9, 3.8097158144618387`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"b9ba9e81-71ec-4d8f-810a-476a88cd5241"],

Cell[BoxData[
 RowBox[{
  RowBox[{"G\[Mu]", "=", "0.00001166"}], ";"}]], "Input",
 CellChangeTimes->{{3.8097166619633474`*^9, 3.8097166631113186`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"dd2a7a59-73f0-48fc-af22-abaea0dd0700"],

Cell["weak mixing", "Item",
 CellChangeTimes->{{3.8097215140189776`*^9, 
  3.809721517165028*^9}},ExpressionUUID->"be04b616-f18e-485e-b1d2-\
100abfe30b16"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CW", "=", 
   FractionBox[
    RowBox[{"masses", "[", "\"\<W\>\"", "]"}], 
    RowBox[{"masses", "[", "\"\<Z\>\"", "]"}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SW", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["CW", "2"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.809716287203569*^9, 3.8097162905915766`*^9}, {
  3.809716343255684*^9, 3.809716391036676*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"afe0f70b-f90e-4b43-9c18-4aabd6e8e58b"],

Cell["eq. (18)", "Item",
 CellChangeTimes->{{3.809715803121827*^9, 
  3.8097158066098366`*^9}},ExpressionUUID->"e380db53-2322-4877-b3b0-\
326fc2a592ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deOverePrefactor", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "7"}]], "*", "3", " ", 
     SuperscriptBox["10", "8"], "*", "6.58", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "16"}]]}], ")"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Sqrt]", "2"}], 
      RowBox[{"\[Alpha]em", "[", "\"\<Z\>\"", "]"}], " ", "G\[Mu]", " ", 
      RowBox[{"masses", "[", "\"\<e\>\"", "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"64", 
      SuperscriptBox["\[Pi]", "3"]}], ")"}], 
    RowBox[{"(*", " ", "cm", " ", "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8013330364168363`*^9, 3.801333069706184*^9}, {
   3.801333442623082*^9, 3.801333455776955*^9}, 3.8013343772421236`*^9, 
   3.801343748901089*^9, {3.801509459270452*^9, 3.801509465574605*^9}, {
   3.8015104028640594`*^9, 3.80151042245111*^9}, {3.8015106720623426`*^9, 
   3.8015106753421707`*^9}, {3.8015126273856497`*^9, 3.801512649517327*^9}, 
   3.8015128743364363`*^9, 3.805644450764838*^9, {3.8097157012718277`*^9, 
   3.8097157041228285`*^9}, {3.809715789110827*^9, 3.809715790049836*^9}, {
   3.8097165941469994`*^9, 3.8097165949860086`*^9}, {3.8097210230245676`*^9, 
   3.809721024183567*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"d50cd050-68f2-4b2f-bd31-5074fd7d3cb8"],

Cell[BoxData["6.4977394736892285`*^-28"], "Output",
 CellChangeTimes->{
  3.809715704479827*^9, 3.8097157922178507`*^9, 3.8097166011969986`*^9, 
   3.809718813098791*^9, 3.809723188798663*^9, 3.8097269180715613`*^9, 
   3.8097976637637186`*^9, 3.8098079000378056`*^9, 3.809828519177243*^9, 
   3.809871306904682*^9, 3.809872001860396*^9, 3.8098723193227744`*^9, 
   3.8098850717509546`*^9, 3.8100520325671425`*^9, 3.810052259287531*^9, 
   3.810052336536477*^9, {3.8100532085394144`*^9, 3.8100532245031414`*^9}, 
   3.8100640786961217`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"eb54d068-0fda-4fc4-bd99-020b819f3ace"]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"QfEM", "=", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\"\<l\>\"", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"\"\<u\>\"", "\[Rule]", 
       FractionBox["2", "3"]}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["1", "3"]}]}]}], "\[RightAssociation]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.809719916539015*^9, 3.8097199734317617`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"29436073-fe15-4d7a-9273-261eccd83656"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Qw", "[", 
    RowBox[{"I3_", ",", "Q_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"2", "I3"}], "-", 
    RowBox[{"4", "Q", " ", 
     SuperscriptBox["SW", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Qw", "[", "\"\<l\>\"", "]"}], "=", 
   RowBox[{"Qw", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ",", 
     RowBox[{"-", "1"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Qw", "[", "\"\<d\>\"", "]"}], "=", 
   RowBox[{"Qw", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "3"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Qw", "[", "\"\<u\>\"", "]"}], "=", 
   RowBox[{"Qw", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"+", "1"}], "/", "2"}], ",", 
     RowBox[{
      RowBox[{"+", "2"}], "/", "3"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8014333668879766`*^9, 3.801433384513997*^9}, {
   3.8014334377385*^9, 3.8014334898586965`*^9}, {3.8015064918612967`*^9, 
   3.8015064975092983`*^9}, {3.8015126635722733`*^9, 3.801512664537244*^9}, 
   3.8097162364585695`*^9, 3.8097164361835785`*^9, {3.8097197795784564`*^9, 
   3.809719817026455*^9}, 3.8097199247709603`*^9, 3.8097215618490334`*^9},
 CellLabel->"In[9]:=",ExpressionUUID->"7040a96a-2c60-4dfa-ba22-f32459685d47"]
}, Closed]],

Cell[CellGroupData[{

Cell["common functions", "Subsubsection",
 CellChangeTimes->{{3.8097215716750603`*^9, 
  3.809721573603059*^9}},ExpressionUUID->"3a84fe44-9b09-4ef1-9e4e-\
bf76394012d4"],

Cell["eq. (22)", "Item",
 CellChangeTimes->{{3.809714914798916*^9, 
  3.809714916722747*^9}},ExpressionUUID->"5185fa93-dcec-4550-bc58-\
078ffba46c3f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"K\[Lambda]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "x", "-", "y"}], ")"}], "2"], "-", 
    RowBox[{"4", "x", " ", "y"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", 
       RowBox[{"(", 
        RowBox[{"\[Sqrt]", "\[Lambda]"}], ")"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Pi]", "2"], "/", "6"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}], 
        RowBox[{"Log", "[", "x", "]"}], " ", 
        RowBox[{"Log", "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x", "-", "y", "-", 
            RowBox[{"\[Sqrt]", "\[Lambda]"}]}], ")"}], "/", "2"}], "]"}], 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x", "+", "y", "-", 
            RowBox[{"\[Sqrt]", "\[Lambda]"}]}], ")"}], "/", "2"}], "]"}]}], 
       "-", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x", "-", "y", "-", 
            RowBox[{"\[Sqrt]", "\[Lambda]"}]}], ")"}], "/", "2"}]}], "]"}], 
       "-", 
       RowBox[{"PolyLog", "[", 
        RowBox[{"2", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x", "+", "y", "-", 
            RowBox[{"\[Sqrt]", "\[Lambda]"}]}], ")"}], "/", "2"}]}], "]"}]}], 
      ")"}]}], "]"}], "/.", 
   RowBox[{"\[Lambda]", "\[Rule]", 
    RowBox[{"K\[Lambda]", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "x_", "]"}], ":=", 
  RowBox[{"\[CapitalPhi]", "[", 
   RowBox[{"x", ",", "x"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8097152251644506`*^9, 3.809715313780181*^9}, {
  3.809715452527892*^9, 3.80971545504192*^9}, {3.809719617098335*^9, 
  3.8097196255359273`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"ff1e7daf-6115-42e2-8ab0-9df468c657f7"],

Cell["eqs. (34, 37)", "Item",
 CellChangeTimes->{{3.8097154982728853`*^9, 
  3.8097155159598937`*^9}},ExpressionUUID->"d22a5d65-c959-4575-b2cd-\
95f33644d828"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[Xi]", "[", "w_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"$MaxExtraPrecision", "=", "100"}], ",", 
      RowBox[{"$MinPrecision", "=", "50"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Xi]"}], " ", 
      SuperscriptBox[
       RowBox[{"Log", "[", "\[Xi]", "]"}], "2"]}], "-", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"], "w", " ", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        RowBox[{"1", "-", "\[Xi]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", "\[Xi]", "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"], "w"}]}], ")"}], 
      RowBox[{"Log", "[", "\[Xi]", "]"}], 
      RowBox[{"Log", "[", "w", "]"}]}], "+", 
     RowBox[{"\[Xi]", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", "\[Xi]", " ", "w"}]}], ")"}], 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"\[Xi]", " ", "w"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", "\[Xi]", "-", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"2", "-", "\[Xi]", "-", 
           SuperscriptBox["\[Xi]", "2"]}], ")"}], "w"}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Xi]"}], ")"}], "3"], 
         SuperscriptBox["w", "2"]}]}], ")"}], 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"w", ",", 
        RowBox[{"\[Xi]", " ", "w"}]}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8001811607738447`*^9, 3.8001811802759094`*^9}, {
   3.8001812433729973`*^9, 3.8001813173255577`*^9}, 3.8001813672074165`*^9, {
   3.800182005483869*^9, 3.800182047454694*^9}, {3.8003811872046285`*^9, 
   3.8003811918025627`*^9}, {3.8013437237665987`*^9, 3.801343727204919*^9}, {
   3.807561189099946*^9, 3.8075611933239775`*^9}, {3.8098272069609365`*^9, 
   3.8098272114129295`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"27e92e7b-b1bd-4e03-b6d4-9dae0177ca15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"G\[Xi]", "[", "w_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"$MaxExtraPrecision", "=", "100"}], ",", 
      RowBox[{"$MinPrecision", "=", "50"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], "\[Xi]"}], "-", 
     RowBox[{"2", "\[Xi]", " ", 
      RowBox[{"Log", "[", "\[Xi]", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[Xi]", " ", "w"}]}], ")"}], "2"], 
         SuperscriptBox["w", "2"]], "-", "\[Xi]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", "\[Xi]", "]"}], 
         RowBox[{"Log", "[", 
          RowBox[{"\[Xi]", " ", "w"}], "]"}]}], "+", 
        RowBox[{"2", 
         RowBox[{"PolyLog", "[", 
          RowBox[{"2", ",", 
           RowBox[{"1", "-", 
            FractionBox["1", 
             RowBox[{"\[Xi]", " ", "w"}]]}]}], "]"}]}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Xi]", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"3", "\[Xi]"}]}], ")"}]}], "-", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", "\[Xi]"}]}], ")"}], "w"}]}], 
         SuperscriptBox["w", "2"]], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"], "\[Xi]", " ", "w"}]}], 
       ")"}], 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"w", ",", 
        RowBox[{"\[Xi]", " ", "w"}]}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.800182226367705*^9, 3.80018234917892*^9}, {
   3.8003811180018954`*^9, 3.800381143266632*^9}, {3.8075611950279484`*^9, 
   3.807561196886972*^9}, 3.809827217127968*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"c84fb399-5b67-445d-8ea4-d6bae45c686c"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "k"], TraditionalForm]],ExpressionUUID->
  "7e5d81a0-2fa5-4553-af38-ff8e3a047565"],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["H", "+"], 
     SuperscriptBox["H", "-"]}]}], TraditionalForm]],ExpressionUUID->
  "b2c740a7-500e-4bb3-8359-6de7c441ccc7"],
 " couplings"
}], "Subsection",
 CellChangeTimes->{{3.8097215985050335`*^9, 3.809721613396044*^9}, {
  3.809727368897236*^9, 
  3.809727392805168*^9}},ExpressionUUID->"7d855627-330f-409b-abdd-\
de23fa369931"],

Cell["eq. (11)", "Item",
 CellChangeTimes->{{3.8097274097661667`*^9, 
  3.8097274119722633`*^9}},ExpressionUUID->"0bcff78e-d19b-49d0-a922-\
711c068b015c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]kHH", "[", "k_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"k", ",", "1"}], "]"}], 
    RowBox[{"Z", "[", "3", "]"}]}], "+", 
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"Z", "[", "7", "]"}], 
     RowBox[{"q", "[", 
      RowBox[{"k", ",", "2"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.8097216218134375`*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"80c49d9a-d75b-4279-bbf4-f06368b12540"]
}, Closed]],

Cell[CellGroupData[{

Cell["fermion couplings", "Subsection",
 CellChangeTimes->{{3.809715969973357*^9, 
  3.8097159734803553`*^9}},ExpressionUUID->"c19a04b2-cc25-403a-ac92-\
002bf533256f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"T3", "=", 
   RowBox[{"<|", 
    RowBox[{
     RowBox[{"\"\<u\>\"", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{"\"\<d\>\"", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}]}], ",", 
     RowBox[{"\"\<l\>\"", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}]}]}], "|>"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.809718033011702*^9, 3.8097180744405594`*^9}, {
   3.8097181053725615`*^9, 3.809718130328788*^9}, {3.8097182129058104`*^9, 
   3.8097182164057674`*^9}, 3.809718262831537*^9, 3.8097183335193925`*^9, 
   3.809718596345416*^9},
 CellLabel->"In[19]:=",ExpressionUUID->"04069d94-15c6-41e6-8077-e27ae1b9dd02"],

Cell[CellGroupData[{

Cell["relative couplings from eq. (12)", "Item",
 CellChangeTimes->{{3.8097178430977907`*^9, 3.8097178506656513`*^9}, {
  3.8097195618673525`*^9, 
  3.8097195618673525`*^9}},ExpressionUUID->"8ba5f747-6b0c-4f75-9072-\
d1c5ae5b3033"],

Cell["fType \[Element] {\"u\[CloseCurlyDoubleQuote], \"d\", \"l\"}", "Subitem",
 CellChangeTimes->{{3.8097178430977907`*^9, 3.8097178506656513`*^9}, {
  3.80971956473337*^9, 
  3.809719589391368*^9}},ExpressionUUID->"9ebb63ae-55dc-4a36-af23-\
e29096e205aa"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cf\[DoubleStruckOne]", "[", 
   RowBox[{"k_", ",", "fType_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"q", "[", 
    RowBox[{"k", ",", "1"}], "]"}], "-", 
   RowBox[{"2", 
    RowBox[{"T3", "[", "fType", "]"}], " ", 
    RowBox[{"c", "[", "fType", "]"}], 
    RowBox[{"Re", "@", 
     RowBox[{"q", "[", 
      RowBox[{"k", ",", "2"}], "]"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
   RowBox[{"k_", ",", "fType_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Im", "@", 
    RowBox[{"q", "[", 
     RowBox[{"k", ",", "2"}], "]"}]}], 
   RowBox[{"c", "[", "fType", "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.8097178557325993`*^9, 3.809717915468794*^9}, {
  3.8097179527165136`*^9, 3.809718024497738*^9}, {3.809718056844552*^9, 
  3.809718061747561*^9}, {3.8097189890059624`*^9, 3.809718995714961*^9}, {
  3.8097193856556115`*^9, 3.8097193904085803`*^9}, {3.8097195376683817`*^9, 
  3.8097195573033414`*^9}, {3.8097195888673186`*^9, 3.8097195958244905`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"801f1fd9-96a0-48a9-9353-0cdbe2afc224"],

Cell["eqs. (13-16)", "Item",
 CellChangeTimes->{{3.8097178261188145`*^9, 
  3.8097178368528013`*^9}},ExpressionUUID->"731bbb0d-98f4-472e-86f5-\
56d9ecdbf8c9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "\"\<d\>\"", "]"}], "[", "typeindex_", "]"}], ":=", 
   RowBox[{
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<Type 1\>\"", "\[Rule]", 
       RowBox[{"Cot", "[", "\[Beta]", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Type 2\>\"", "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"Tan", "[", "\[Beta]", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Lepton Specific\>\"", "\[Rule]", 
       RowBox[{"Cot", "[", "\[Beta]", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Flipped\>\"", "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"Tan", "[", "\[Beta]", "]"}]}]}]}], "\[IndentingNewLine]", 
     "|>"}], "[", "typeindex", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "\"\<l\>\"", "]"}], "[", "typeindex_", "]"}], ":=", 
   RowBox[{
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<Type 1\>\"", "\[Rule]", 
       RowBox[{"Cot", "[", "\[Beta]", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Type 2\>\"", "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"Tan", "[", "\[Beta]", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Lepton Specific\>\"", "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"Tan", "[", "\[Beta]", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Flipped\>\"", "\[Rule]", 
       RowBox[{"Cot", "[", "\[Beta]", "]"}]}]}], "\[IndentingNewLine]", 
     "|>"}], "[", "typeindex", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "\"\<u\>\"", "]"}], "[", "typeindex_", "]"}], ":=", 
   RowBox[{"-", 
    RowBox[{"Cot", "[", "\[Beta]", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.809716966542939*^9, 3.8097170115715103`*^9}, {
   3.80971705862354*^9, 3.8097171493485003`*^9}, 3.8097172032543955`*^9, {
   3.809877103342094*^9, 3.809877117005591*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"7db7ee34-5e7a-49ef-81c2-251eea8bde4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"specificTypeReplacement", "[", "typeindex_", "]"}], "=", 
   RowBox[{
    RowBox[{"c", "[", "f_", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"c", "[", "f", "]"}], "[", "typeindex", "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8097172402547684`*^9, 3.809717267468774*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"5f38f525-4430-4406-8387-864539708326"],

Cell["for example", "Item",
 CellChangeTimes->{{3.809717330777526*^9, 
  3.8097173357455263`*^9}},ExpressionUUID->"4b360739-ea39-45dd-a170-\
5ca80fe0f2f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c", "[", "\"\<d\>\"", "]"}], ",", 
    RowBox[{"c", "[", "\"\<u\>\"", "]"}], ",", 
    RowBox[{"c", "[", "\"\<l\>\"", "]"}]}], "}"}], "/.", 
  RowBox[{"specificTypeReplacement", "[", "\"\<Flipped\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.8097172157497954`*^9, 3.8097172249467635`*^9}, {
  3.8097172721737757`*^9, 3.8097173034435573`*^9}, {3.8098769583903275`*^9, 
  3.8098769648353357`*^9}, {3.809877121973628*^9, 3.809877122793644*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"282d4b27-d671-4f5f-ace7-d96b8dbe3e12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Tan", "[", "\[Beta]", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"Cot", "[", "\[Beta]", "]"}]}], ",", 
   RowBox[{"Cot", "[", "\[Beta]", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8097171413584995`*^9, {3.8097172133727636`*^9, 3.8097172220667634`*^9}, {
   3.8097172763717637`*^9, 3.8097173055525255`*^9}, 3.8097185998014145`*^9, 
   3.8097188133517923`*^9, 3.8097231889696856`*^9, 3.8097269190155354`*^9, 
   3.8097976638487167`*^9, 3.809807900121834*^9, 3.809828519803237*^9, 
   3.809871307042655*^9, 3.8098720020163956`*^9, 3.809872319434803*^9, {
   3.809876961132352*^9, 3.8098769655973563`*^9}, {3.8098771198785434`*^9, 
   3.809877123046633*^9}, 3.8098850718949857`*^9, 3.810052032706166*^9, 
   3.8100522593635674`*^9, 3.810052336655475*^9, {3.8100532086224136`*^9, 
   3.8100532245861416`*^9}, 3.8100640787691226`*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"0053e624-c388-4677-8bcf-d16734c5119e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["individual contributions to the electron edm", "Subsection",
 CellChangeTimes->{{3.8097147373677073`*^9, 3.8097147452626953`*^9}, {
  3.8097209752145367`*^9, 
  3.8097209774255285`*^9}},ExpressionUUID->"3fe49e15-277d-4aec-af9e-\
42bcd817ce2f"],

Cell[CellGroupData[{

Cell["\<\
note on how the relative couplings to fermions appear in the expressions:\
\>", "Item",
 CellChangeTimes->{{3.809809233259967*^9, 
  3.8098092493819675`*^9}},ExpressionUUID->"fa1d3300-5b3c-4017-a29f-\
9fccb8292dec"],

Cell[CellGroupData[{

Cell["\<\
instead of writing out the relative fermion-higgs couplings eq. (12), write,\
\>", "Subitem",
 CellChangeTimes->{{3.809809233259967*^9, 3.809809251188938*^9}, {
  3.8098774490177794`*^9, 
  3.809877508777385*^9}},ExpressionUUID->"d00e81d2-4d30-462f-b9f6-\
252e555c2349"],

Cell[TextData[{
 "Cf\[DoubleStruckOne][k] \[Congruent] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["q", "k1"], TraditionalForm]],ExpressionUUID->
  "0531724c-d3e8-49e6-9a00-41ba90909c93"],
 "- ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    SubsuperscriptBox["T", "3", "f"]}], TraditionalForm]],ExpressionUUID->
  "ac4425c2-69d2-4163-a268-93cf9ee0e738"],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "f"], TraditionalForm]],ExpressionUUID->
  "9a2118af-f971-4dae-b410-69853235829c"],
 Cell[BoxData[
  FormBox[
   RowBox[{"Re", "(", 
    SubscriptBox["q", "k2"], ")"}], TraditionalForm]],ExpressionUUID->
  "305190c3-04e5-4a0d-a718-1fef3bd8a5b1"]
}], "Subitem",
 CellChangeTimes->{{3.809809233259967*^9, 3.809809251188938*^9}, {
  3.8098774490177794`*^9, 
  3.8098775863676777`*^9}},ExpressionUUID->"5aa31094-301c-43e6-952a-\
4a963ed3bbd2"],

Cell[TextData[{
 "Cf\[ImaginaryI]\[Gamma]5[k] \[Congruent] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "f"], TraditionalForm]],ExpressionUUID->
  "e4fe8e27-1a5c-443a-9a7d-4ff7287731f8"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Im", "(", 
    SubscriptBox["q", "k2"], ")"}], TraditionalForm]],ExpressionUUID->
  "1c79d5db-727c-4323-92d3-720b474f798f"]
}], "Subitem",
 CellChangeTimes->{{3.809809233259967*^9, 3.809809251188938*^9}, {
  3.8098774490177794`*^9, 
  3.809877608071769*^9}},ExpressionUUID->"3d53cffa-a838-4083-9356-\
2b5adaf332fc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (24) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", "f", "EM"], TraditionalForm]],ExpressionUUID->
  "9980097d-8749-477e-ab50-387dbcdac68d"],
 ": electromagnetic fermion loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.8001796197898536`*^9, 3.800179622733528*^9}, {
   3.8001798475474167`*^9, 3.8001798634674606`*^9}, {3.800180825862047*^9, 
   3.8001808340961213`*^9}, {3.8001809083981237`*^9, 3.800180914794088*^9}, {
   3.8001820227969894`*^9, 3.8001820230302615`*^9}, {3.8013252412947416`*^9, 
   3.801325241633678*^9}, {3.8014031282020807`*^9, 3.801403128444075*^9}, 
   3.801404985773706*^9, {3.8097160143587923`*^9, 
   3.8097160437127852`*^9}},ExpressionUUID->"adb26510-9b39-4af0-80bd-\
d3b77aecc9a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fEM", "[", 
    RowBox[{"k_", ",", "fType_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "4"}], ")"}], " ", "NC", "  ", 
    SuperscriptBox[
     RowBox[{"QfEM", "[", "fType", "]"}], "2"], 
    RowBox[{"QfEM", "[", "\"\<l\>\"", "]"}], "*", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
        RowBox[{"k", ",", "fType"}], "]"}], " ", 
       RowBox[{"Cf\[DoubleStruckOne]", "[", 
        RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
       RowBox[{"r", "[", "k", "]"}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"r", "[", "k", "]"}], "]"}]}], "+", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Cf\[DoubleStruckOne]", "[", 
        RowBox[{"k", ",", "fType"}], "]"}], 
       RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
        RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
       RowBox[{"r", "[", "k", "]"}], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"r", "[", "k", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", 
             RowBox[{"r", "[", "k", "]"}]}]}], ")"}], 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"r", "[", "k", "]"}], "]"}]}]}], ")"}]}]}], 
     "\[IndentingNewLine]", ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001796781354065`*^9, 3.800179839607561*^9}, {
   3.8001798706244583`*^9, 3.800179899047504*^9}, {3.8001799576613235`*^9, 
   3.800180046297371*^9}, {3.800180094570043*^9, 3.8001801408867626`*^9}, {
   3.8001802252293434`*^9, 3.800180229434305*^9}, {3.8001804078786182`*^9, 
   3.8001804099614067`*^9}, 3.8001807155309095`*^9, {3.800181367210417*^9, 
   3.8001813672114167`*^9}, {3.800382377437338*^9, 3.8003824332782145`*^9}, {
   3.800382484895833*^9, 3.8003825164308357`*^9}, {3.8013334801727486`*^9, 
   3.801333500795998*^9}, 3.8013337816736097`*^9, 3.8013342234549236`*^9, {
   3.801408051794347*^9, 3.8014080603973675`*^9}, {3.801408156777264*^9, 
   3.801408159543292*^9}, {3.801514087806153*^9, 3.801514087868126*^9}, 
   3.8097175665712967`*^9, {3.8097176802282953`*^9, 3.809717730004615*^9}, {
   3.809717783922615*^9, 3.8097177928906317`*^9}, {3.80971838801416*^9, 
   3.809718394670128*^9}, {3.8097184668571153`*^9, 3.809718468157115*^9}, {
   3.809718503637915*^9, 3.809718565442424*^9}, {3.8097186342634916`*^9, 
   3.8097186391194916`*^9}, {3.8097190850238934`*^9, 3.809719086615927*^9}, 
   3.809719903166967*^9, {3.809720155336928*^9, 3.809720158755907*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"e946f9cd-8c9f-4b5a-9359-80b44ccffdca"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]fEMtop", "[", "k_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Delta]fEM", "[", 
    RowBox[{"k", ",", "\"\<u\>\""}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NC", "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"masses", "[", "\"\<t\>\"", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], 
    "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fEMbottom", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Delta]fEM", "[", 
     RowBox[{"k", ",", "\"\<d\>\""}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NC", "\[Rule]", "3"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<b\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fEMtau", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Delta]fEM", "[", 
     RowBox[{"k", ",", "\"\<l\>\""}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NC", "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<\[Tau]\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8001804803092937`*^9, 3.800180725243101*^9}, 
   3.8001811355452194`*^9, {3.8014080632353687`*^9, 3.801408115723257*^9}, {
   3.8014131008765373`*^9, 3.801413109118615*^9}, {3.8015140905029073`*^9, 
   3.8015140943243055`*^9}, {3.8015141769922466`*^9, 3.801514193969283*^9}, {
   3.805675838961449*^9, 3.8056758392074738`*^9}, 3.8056759014874344`*^9, {
   3.809718577476415*^9, 3.809718584852415*^9}, {3.8097186422614927`*^9, 
   3.8097186562935004`*^9}, {3.8097190897599206`*^9, 3.809719141683793*^9}, {
   3.8097199052550125`*^9, 3.809719908184991*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"585cfd72-2d76-4fce-b60c-5b415942890e"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (25) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", "f", "NC"], TraditionalForm]],ExpressionUUID->
  "a797a0b9-3002-4d0a-9e30-c814cd3fb487"],
 ": neutral-current fermion loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.8001796197898536`*^9, 3.800179622733528*^9}, {
  3.8001798475474167`*^9, 3.8001798634674606`*^9}, {3.800180825862047*^9, 
  3.8001808340961213`*^9}, {3.8001809083981237`*^9, 3.800180914794088*^9}, {
  3.8001820227969894`*^9, 3.8001820230302615`*^9}, {3.8013252412947416`*^9, 
  3.801325241633678*^9}, {3.8014031400551677`*^9, 3.8014031415482316`*^9}, {
  3.801403621099292*^9, 3.8014036212312403`*^9}, {3.809719322229718*^9, 
  3.809719332757599*^9}},ExpressionUUID->"2f31f6a6-16b6-4020-b1e5-\
0cfd73263479"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fNC", "[", 
    RowBox[{"k_", ",", "fType_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", " ", "NC"}], " ", 
      RowBox[{"QfEM", "[", "fType", "]"}], " ", 
      RowBox[{"Qw", "[", "fType", "]"}], " ", 
      RowBox[{"Qw", "[", "\"\<l\>\"", "]"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox["CW", "2"], 
      SuperscriptBox["SW", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
        RowBox[{"k", ",", "fType"}], "]"}], 
       RowBox[{"Cf\[DoubleStruckOne]", "[", 
        RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
       FractionBox[
        RowBox[{"r", "[", "k", "]"}], 
        RowBox[{"1", "-", 
         RowBox[{"z", "[", "k", "]"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"r", "[", "k", "]"}], "]"}], "-", 
         RowBox[{"\[CapitalPhi]", "[", 
          FractionBox[
           RowBox[{"r", "[", "k", "]"}], 
           RowBox[{"z", "[", "k", "]"}]], "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cf\[DoubleStruckOne]", "[", 
        RowBox[{"k", ",", "fType"}], "]"}], 
       RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
        RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
       FractionBox[
        RowBox[{"r", "[", "k", "]"}], 
        RowBox[{"1", "-", 
         RowBox[{"z", "[", "k", "]"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"z", "[", "k", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", 
             RowBox[{"r", "[", "k", "]"}]}]}], ")"}], 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"r", "[", "k", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"2", 
              RowBox[{"r", "[", "k", "]"}]}], 
             RowBox[{"z", "[", "k", "]"}]]}], ")"}], 
          RowBox[{"\[CapitalPhi]", "[", 
           FractionBox[
            RowBox[{"r", "[", "k", "]"}], 
            RowBox[{"z", "[", "k", "]"}]], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8001796781354065`*^9, 3.800179839607561*^9}, {
   3.8001798706244583`*^9, 3.800179899047504*^9}, {3.8001799576613235`*^9, 
   3.800180046297371*^9}, {3.800180094570043*^9, 3.8001801408867626`*^9}, {
   3.8001802252293434`*^9, 3.800180229434305*^9}, {3.8001804078786182`*^9, 
   3.8001804099614067`*^9}, 3.8001807155309095`*^9, {3.800181367210417*^9, 
   3.8001813672114167`*^9}, {3.800382377437338*^9, 3.8003824332782145`*^9}, {
   3.800382484895833*^9, 3.8003825164308357`*^9}, {3.8013334801727486`*^9, 
   3.801333500795998*^9}, 3.8013337816736097`*^9, 3.8013342234549236`*^9, {
   3.801403152905197*^9, 3.8014031778151913`*^9}, {3.8014033042119336`*^9, 
   3.8014033588409834`*^9}, {3.8014034276149845`*^9, 3.801403429906986*^9}, {
   3.8014034905469894`*^9, 3.801403502153016*^9}, {3.801404206448906*^9, 
   3.8014042494969544`*^9}, {3.801404641735941*^9, 3.8014047254518876`*^9}, {
   3.80140476438663*^9, 3.8014047659876537`*^9}, {3.801513663758893*^9, 
   3.8015136639337907`*^9}, {3.801514022285518*^9, 3.801514022907487*^9}, {
   3.8015155581930695`*^9, 3.801515558330795*^9}, {3.809719341389589*^9, 
   3.8097193765986323`*^9}, {3.809719605425462*^9, 3.8097196476889205`*^9}, {
   3.8097196780025916`*^9, 3.809719679179598*^9}, {3.809719713961768*^9, 
   3.8097197277417974`*^9}, {3.8097198670889616`*^9, 3.809719897613015*^9}, {
   3.8097200179085064`*^9, 3.8097200217064905`*^9}, {3.809720096740299*^9, 
   3.8097200967993317`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"b1d7b95b-4369-4e08-a287-ef178591a8fd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fNCtop", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Delta]fNC", "[", 
     RowBox[{"k", ",", "\"\<u\>\""}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NC", "\[Rule]", "3"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<t\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fNCbottom", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Delta]fNC", "[", 
     RowBox[{"k", ",", "\"\<d\>\""}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NC", "\[Rule]", "3"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<b\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]fNCtau", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Delta]fNC", "[", 
     RowBox[{"k", ",", "\"\<l\>\""}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NC", "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<\[Tau]\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8001804803092937`*^9, 3.800180725243101*^9}, 
   3.8001811355452194`*^9, {3.8014031816991973`*^9, 3.8014032720539565`*^9}, {
   3.801403331083931*^9, 3.8014033346999826`*^9}, {3.8014033897819834`*^9, 
   3.8014034488989925`*^9}, {3.801513673493338*^9, 3.8015137031801558`*^9}, {
   3.801514025626834*^9, 3.801514037439686*^9}, {3.801515581204565*^9, 
   3.8015156144963484`*^9}, {3.801517412602455*^9, 3.8015174186334805`*^9}, {
   3.8015177776187344`*^9, 3.801517780824727*^9}, {3.809719687280571*^9, 
   3.809719704690696*^9}, {3.809719738465769*^9, 3.8097197544544716`*^9}, {
   3.809719890121013*^9, 3.8097198907010207`*^9}, {3.8097200547962956`*^9, 
   3.8097200891483183`*^9}, {3.809871802200251*^9, 3.809871803268243*^9}, {
   3.809871842236171*^9, 3.8098718428171415`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"63004bc8-ffef-401c-bc96-0a6dc2a989f1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (27) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", 
    SuperscriptBox["H", "+"], "EM"], TraditionalForm]],ExpressionUUID->
  "7f4d0bf1-99b7-4439-b745-08bf15599b87"],
 ": electromagnetic ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["H", "+"], TraditionalForm]],ExpressionUUID->
  "113dcc66-6cac-4681-aa3d-c21f79199ec7"],
 "-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
  3.800182192120495*^9, 3.8001821945455837`*^9}, {3.8014023525478935`*^9, 
  3.8014023623398757`*^9}, {3.8014031355941906`*^9, 3.801403135613139*^9}, {
  3.8097205257312756`*^9, 
  3.809720553082964*^9}},ExpressionUUID->"f70ec4be-3b86-4251-8d44-\
6976e479002e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]HEM", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        RowBox[{"QfEM", "[", "\"\<l\>\"", "]"}], 
        SuperscriptBox["SW", "2"]}], 
       RowBox[{"\[Pi]", " ", 
        RowBox[{"\[Alpha]em", "[", "\"\<Z\>\"", "]"}]}]], 
      RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
       RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
      RowBox[{"\[Lambda]kHH", "[", "k", "]"}], 
      RowBox[{"w", "[", "k", "]"}], 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"Log", "[", 
         RowBox[{"h", "[", "k", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"h", "[", "k", "]"}], 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"h", "[", "k", "]"}], "]"}]}]}], ")"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"h", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox["mHp", "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8014027692177715`*^9, 3.801402773107771*^9}, 
   3.8014028530897927`*^9, {3.801403054292743*^9, 3.8014030576977444`*^9}, {
   3.8014059315544677`*^9, 3.801405931681419*^9}, {3.801406119592424*^9, 
   3.8014061377514467`*^9}, 3.8014067528420525`*^9, {3.801407375729766*^9, 
   3.8014073766807876`*^9}, 3.8014113038439064`*^9, {3.80151114226868*^9, 
   3.801511190447176*^9}, {3.801511231937213*^9, 3.8015112332110634`*^9}, 
   3.8015128621261716`*^9, {3.8015187994314375`*^9, 3.8015187999474535`*^9}, {
   3.8097206016373944`*^9, 3.80972062223151*^9}, {3.8097206523868237`*^9, 
   3.8097206771657705`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"8c46c4bf-4a98-4009-b3f1-2397ad23efd2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (28) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", 
    SuperscriptBox["H", "+"], "NC"], TraditionalForm]],ExpressionUUID->
  "23fc2c6f-26a1-42ee-bf2a-0e7ee038c6f8"],
 ": neutral-current ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["H", "+"], TraditionalForm]],ExpressionUUID->
  "63a9d04d-31c3-42a5-a068-f31130bc27dd"],
 "-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
  3.800182192120495*^9, 3.8001821945455837`*^9}, {3.8014023525478935`*^9, 
  3.8014023623398757`*^9}, {3.8014031355941906`*^9, 3.801403135613139*^9}, {
  3.8097205257312756`*^9, 
  3.8097205911547956`*^9}},ExpressionUUID->"d4434744-1b9a-4226-a291-\
0554cb4ce22f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]HNC", "[", "k_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"Qw", "[", "\"\<l\>\"", "]"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["CW", "2"], "-", 
         SuperscriptBox["SW", "2"]}], ")"}]}], 
      RowBox[{"4", " ", "\[Pi]", " ", 
       RowBox[{"\[Alpha]em", "[", "\"\<Z\>\"", "]"}]}]], 
     RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
      RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
     RowBox[{"\[Lambda]kHH", "[", "k", "]"}], 
     FractionBox[
      RowBox[{"z", "[", "k", "]"}], 
      RowBox[{"1", "-", 
       RowBox[{"z", "[", "k", "]"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"z", "[", "k", "]"}], "]"}], "-", 
       RowBox[{
        RowBox[{"h", "[", "k", "]"}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"h", "[", "k", "]"}], "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"h", "[", "k", "]"}], 
         RowBox[{"z", "[", "k", "]"}]], 
        RowBox[{"\[CapitalPhi]", "[", 
         FractionBox[
          RowBox[{"h", "[", "k", "]"}], 
          RowBox[{"z", "[", "k", "]"}]], "]"}]}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}], ",", 
      RowBox[{
       RowBox[{"h", "[", "x_", "]"}], "\[RuleDelayed]", 
       FractionBox[
        SuperscriptBox["mHp", "2"], 
        SuperscriptBox[
         RowBox[{"mh", "[", "x", "]"}], "2"]]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182441013811*^9, 3.800182458478478*^9}, {3.8001825248680525`*^9, 
   3.8001827919024363`*^9}, {3.800182822277143*^9, 3.8001830105089436`*^9}, {
   3.800183246327523*^9, 3.800183247328679*^9}, {3.800184149408285*^9, 
   3.8001841547729416`*^9}, {3.800381028851209*^9, 3.8003810494948597`*^9}, {
   3.800381105896858*^9, 3.800381108754851*^9}, {3.8013391098013716`*^9, 
   3.8013391106620207`*^9}, {3.8013391541191053`*^9, 3.801339157107849*^9}, 
   3.801344546887469*^9, {3.801353176304164*^9, 3.8013531986301093`*^9}, {
   3.8013532492021093`*^9, 3.801353457955168*^9}, 3.8014028774018*^9, {
   3.801402910180823*^9, 3.8014030369437733`*^9}, {3.8014030689647613`*^9, 
   3.8014030731507783`*^9}, {3.8014063779211073`*^9, 3.801406387786134*^9}, {
   3.8014072089736233`*^9, 3.8014072133636723`*^9}, 3.8014074152645507`*^9, 
   3.8014074569045424`*^9, 3.8014075084895487`*^9, {3.8014075498626184`*^9, 
   3.8014075611716366`*^9}, {3.801506644327469*^9, 3.8015066489706044`*^9}, {
   3.8015068210037985`*^9, 3.801506858253002*^9}, 3.8015111780980253`*^9, {
   3.8015135115546007`*^9, 3.8015135425376635`*^9}, {3.8015136037541904`*^9, 
   3.8015136045140686`*^9}, 3.801518812519272*^9, {3.809720699924741*^9, 
   3.809720728945772*^9}, {3.80980851700609*^9, 3.8098085170851088`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"759b1696-89ab-4de0-a246-ef559d3ab1ea"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (29) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", 
    SuperscriptBox["H", "+"], "CC"], TraditionalForm]],ExpressionUUID->
  "e2473e35-1285-47ef-bfa8-bbf44b50c9b2"],
 ": charged-current ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["H", "+"], TraditionalForm]],ExpressionUUID->
  "db6ddb5c-edda-4518-8f0d-576db08df2a6"],
 "-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
   3.800182192120495*^9, 3.8001821945455837`*^9}, {3.8014023525478935`*^9, 
   3.8014023623398757`*^9}, {3.8014031355941906`*^9, 3.801403135613139*^9}, {
   3.8097205257312756`*^9, 3.8097205965197515`*^9}, {3.8097208812479343`*^9, 
   3.8097208858277335`*^9}, 
   3.81005320099393*^9},ExpressionUUID->"49a41768-de80-486a-957b-\
2103045c7b30"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]HCC", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"T3", "[", "\"\<l\>\"", "]"}]}], 
      RowBox[{"4", " ", "\[Pi]", " ", 
       RowBox[{"\[Alpha]em", "[", "\"\<Z\>\"", "]"}]}]], 
     RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
      RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
     RowBox[{"\[Lambda]kHH", "[", "k", "]"}], 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       FractionBox["2", 
        RowBox[{"h", "[", "k", "]"}]], "+", 
       FractionBox[
        RowBox[{"2", 
         RowBox[{"Log", "[", 
          RowBox[{"h", "[", "k", "]"}], "]"}]}], 
        RowBox[{"h", "[", "k", "]"}]], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{"2", 
             RowBox[{"h", "[", "k", "]"}]}], "+", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}], ")"}], 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], "/", 
          RowBox[{"w", "[", "k", "]"}]}], "]"}]}], "\[IndentingNewLine]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"h", "[", "k", "]"}], "2"], "-", 
            RowBox[{
             RowBox[{"h", "[", "k", "]"}], 
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"w", "[", "k", "]"}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"w", "[", "k", "]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", "k", "]"}], "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}]}], ")"}]}], ")"}], 
        RowBox[{"Log", "[", 
         RowBox[{"h", "[", "k", "]"}], "]"}], 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], "/", 
          RowBox[{"w", "[", "k", "]"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", "k", "]"}], "-", 
              RowBox[{"2", 
               SuperscriptBox[
                RowBox[{"h", "[", "k", "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"h", "[", "k", "]"}], "3"], "+", 
              RowBox[{"w", "[", "k", "]"}], "-", 
              RowBox[{"2", 
               RowBox[{"h", "[", "k", "]"}], 
               RowBox[{"w", "[", "k", "]"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h", "[", "k", "]"}], "2"], 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}], ")"}], 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"h", "[", "k", "]"}]}]}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"w", "[", "k", "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"4", 
               RowBox[{"h", "[", "k", "]"}]}], "+", 
              RowBox[{"2", 
               SuperscriptBox[
                RowBox[{"h", "[", "k", "]"}], "2"]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"h", "[", "k", "]"}], "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", "k", "]"}], "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}]}], ")"}]}], ")"}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"h", "[", "k", "]"}], "]"}]}], "\[IndentingNewLine]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"h", "[", "k", "]"}], "3"], "-", 
            RowBox[{"w", "[", "k", "]"}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"h", "[", "k", "]"}], "2"], 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", 
                RowBox[{"w", "[", "k", "]"}]}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"h", "[", "k", "]"}], 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"w", "[", "k", "]"}], "+", 
               SuperscriptBox[
                RowBox[{"w", "[", "k", "]"}], "2"]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"w", "[", "k", "]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"h", "[", "k", "]"}], "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}]}], ")"}]}], ")"}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], ",", 
          RowBox[{"w", "[", "k", "]"}]}], "]"}]}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"h", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox["mHp", "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}]}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182441013811*^9, 3.800182458478478*^9}, {3.8001825248680525`*^9, 
   3.8001827919024363`*^9}, {3.800182822277143*^9, 3.8001830105089436`*^9}, {
   3.800183246327523*^9, 3.800183247328679*^9}, {3.800184149408285*^9, 
   3.8001841547729416`*^9}, {3.800381028851209*^9, 3.8003810494948597`*^9}, {
   3.800381105896858*^9, 3.800381108754851*^9}, {3.8013391098013716`*^9, 
   3.8013391106620207`*^9}, {3.8013391541191053`*^9, 3.801339157107849*^9}, 
   3.801344546887469*^9, 3.801355266652813*^9, {3.8013553046946936`*^9, 
   3.8013555855660763`*^9}, {3.8013562336772385`*^9, 
   3.8013562517027636`*^9}, {3.8013565619031963`*^9, 3.8013565729357247`*^9}, 
   3.801356768090451*^9, {3.801360200836999*^9, 3.8013602023779974`*^9}, {
   3.8014086388526554`*^9, 3.801408657797676*^9}, {3.801511097815618*^9, 
   3.8015111130517406`*^9}, 3.801512859566641*^9, 3.8015187866374617`*^9, {
   3.8076465417132816`*^9, 3.807646554594231*^9}, {3.809720779918748*^9, 
   3.809720847422826*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"12c11dc4-1deb-4dc1-ae45-9be8f9cff30c"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (30, 32) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", "W", "EM"], TraditionalForm]],ExpressionUUID->
  "a0c8f1ef-b243-46c7-bb35-2854add3c9d8"],
 ": electromagnetic W-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.801335184061271*^9, 3.801335186077608*^9}, 
   3.809719183818782*^9, {3.809719218416972*^9, 3.809719233946942*^9}, 
   3.809720565584792*^9},ExpressionUUID->"9dd87468-c79e-49a3-a75a-\
87caaa896777"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]WEM", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"QfEM", "[", "\"\<l\>\"", "]"}], 
     RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
      RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
     RowBox[{"q", "[", 
      RowBox[{"k", ",", "1"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"6", 
           RowBox[{"w", "[", "k", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"6", 
           RowBox[{"w", "[", "k", "]"}]}]}], ")"}], 
        RowBox[{"Log", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"16", 
           RowBox[{"w", "[", "k", "]"}]}], "+", 
          RowBox[{"12", 
           SuperscriptBox[
            RowBox[{"w", "[", "k", "]"}], "2"]}]}], ")"}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "+", 
       RowBox[{"2", 
        RowBox[{"Log", "[", "\[Xi]", "]"}]}], "+", 
       RowBox[{"F\[Xi]", "[", 
        RowBox[{"w", "[", "k", "]"}], "]"}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
      RowBox[{"SetPrecision", "[", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182363486722*^9, 3.8001823680018177`*^9}, {3.8001832420146446`*^9, 
   3.800183243799141*^9}, {3.8001840696767116`*^9, 3.8001840867785263`*^9}, {
   3.8001847520213957`*^9, 3.8001847536408563`*^9}, 3.8001848202949295`*^9, 
   3.800381221111555*^9, {3.801333073062358*^9, 3.801333073371834*^9}, 
   3.801333150664748*^9, 3.80133507912181*^9, 3.801337313786971*^9, 
   3.8013373439327574`*^9, {3.8014083374680986`*^9, 3.8014083504600916`*^9}, {
   3.8014083967900963`*^9, 3.8014083987141037`*^9}, {3.8014084487251897`*^9, 
   3.801408452824212*^9}, {3.8015108105416813`*^9, 3.801510819801545*^9}, 
   3.8056014441719704`*^9, {3.809720213609198*^9, 3.8097202313672223`*^9}, {
   3.8097202626801896`*^9, 3.80972027752623*^9}, {3.8100529114391136`*^9, 
   3.8100529212940207`*^9}, {3.8100531739901943`*^9, 3.810053181375744*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"6037cbae-a444-44d2-813d-36fc98e65f9f"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (31, 33) ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Delta]", "W", "NC"], TraditionalForm]],ExpressionUUID->
  "9b8205f2-9b5f-4c8a-b5f8-620a1178b278"],
 ": neutral-current W-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.801335184061271*^9, 3.801335186077608*^9}, 
   3.809719183818782*^9, {3.809719218416972*^9, 3.809719233946942*^9}, {
   3.8097192823099437`*^9, 3.8097192947656755`*^9}, 
   3.809720565990738*^9},ExpressionUUID->"71b6aa65-053f-4e70-9fc0-\
cdfc5ab37e3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]WNC", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"Qw", "[", "\"\<l\>\"", "]"}], 
      RowBox[{"4", " ", 
       SuperscriptBox["SW", "2"]}]], 
     RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
      RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
     RowBox[{"q", "[", 
      RowBox[{"k", ",", "1"}], "]"}], 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", "-", 
           RowBox[{"16", 
            RowBox[{"w", "[", "k", "]"}]}], "+", 
           RowBox[{"12", 
            SuperscriptBox[
             RowBox[{"w", "[", "k", "]"}], "2"]}]}], 
          RowBox[{"1", "-", 
           RowBox[{"z", "[", "k", "]"}]}]]}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"2", 
           SuperscriptBox["SW", "2"]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"6", 
              SuperscriptBox["SW", "2"]}]}], ")"}], 
           RowBox[{"w", "[", "k", "]"}]}]}], 
         RowBox[{
          SuperscriptBox["CW", "2"], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"z", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"Log", "[", 
         RowBox[{"z", "[", "k", "]"}], "]"}]}], "\[IndentingNewLine]", "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"8", 
             SuperscriptBox["SW", "2"]}], "-", 
            RowBox[{"12", 
             SuperscriptBox["SW", "4"]}]}], ")"}], 
          RowBox[{"z", "[", "k", "]"}]}], 
         RowBox[{"1", "-", 
          RowBox[{"z", "[", "k", "]"}]}]], 
        RowBox[{"\[CapitalPhi]", "[", 
         SuperscriptBox["CW", "2"], "]"}]}], "+", 
       RowBox[{"\[Xi]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", 
           SuperscriptBox["SW", "2"]}]}], ")"}], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"\[Xi]", " ", 
          SuperscriptBox["CW", "2"]}], "]"}]}], "+", 
       RowBox[{"F\[Xi]", "[", 
        RowBox[{"w", "[", "k", "]"}], "]"}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"z", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}]}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182363486722*^9, 3.8001823680018177`*^9}, {3.8001832420146446`*^9, 
   3.800183243799141*^9}, {3.8001840696767116`*^9, 3.8001840867785263`*^9}, {
   3.8001847520213957`*^9, 3.8001847536408563`*^9}, 3.8001848202949295`*^9, 
   3.800381221111555*^9, {3.801333073062358*^9, 3.801333073371834*^9}, 
   3.801333150664748*^9, 3.80133507912181*^9, 3.801337313786971*^9, 
   3.8013373439327574`*^9, {3.8014083374680986`*^9, 3.8014083504600916`*^9}, {
   3.8014083967900963`*^9, 3.8014083987141037`*^9}, {3.8014084487251897`*^9, 
   3.801408452824212*^9}, {3.8015108105416813`*^9, 3.801510819801545*^9}, 
   3.8056014441719704`*^9, 3.809719280826949*^9, {3.8097203394085646`*^9, 
   3.8097203579445953`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"7ccf886d-c374-4911-928e-86b1d94d9993"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (35, 36)",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubsuperscriptBox["\[Delta]", "W", "CC"]}], TraditionalForm]],
  ExpressionUUID->"3d2cf426-2a9c-421f-a3d8-e90c5cbe8f88"],
 ": charged-current W-loop contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
   3.800182192120495*^9, 3.800182203219565*^9}, {3.8013460807650247`*^9, 
   3.8013460836670246`*^9}, {3.8013543217713585`*^9, 3.801354321772365*^9}, {
   3.809720404940596*^9, 3.809720428105669*^9}, 
   3.809720566748764*^9},ExpressionUUID->"32a6d424-b70f-497f-8052-\
b78e5b055302"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]WCC", "[", "k_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       SuperscriptBox["SW", "2"]}]], 
     RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
      RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
     RowBox[{"q", "[", 
      RowBox[{"k", ",", "1"}], "]"}], 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       FractionBox["2", 
        RowBox[{"w", "[", "k", "]"}]], "-", 
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}], "2"]}], 
        RowBox[{
         RowBox[{"h", "[", "k", "]"}], 
         RowBox[{"w", "[", "k", "]"}]}]], "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"w", "[", "k", "]"}]}], ")"}], 
           SuperscriptBox[
            RowBox[{"w", "[", "k", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"w", "[", "k", "]"}]}], ")"}], 
           SuperscriptBox[
            RowBox[{"h", "[", "k", "]"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"h", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"w", "[", "k", "]"}], "-", 
             RowBox[{"7", 
              SuperscriptBox[
               RowBox[{"w", "[", "k", "]"}], "2"]}]}], ")"}]}]}], 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], 
          RowBox[{"w", "[", "k", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"Log", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "\[IndentingNewLine]", "+", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"h", "[", "k", "]"}], "2"], "-", 
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"h", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"7", 
              RowBox[{"w", "[", "k", "]"}]}]}], ")"}]}]}], 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"Log", "[", 
         RowBox[{"h", "[", "k", "]"}], "]"}]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"w", "[", "k", "]"}]}], ")"}], "3"], "-", 
          RowBox[{"3", 
           SuperscriptBox[
            RowBox[{"h", "[", "k", "]"}], "2"], 
           RowBox[{"w", "[", "k", "]"}]}], "-", 
          RowBox[{
           RowBox[{"h", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", 
              RowBox[{"w", "[", "k", "]"}]}], "-", 
             RowBox[{"4", 
              SuperscriptBox[
               RowBox[{"w", "[", "k", "]"}], "2"]}]}], ")"}]}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h", "[", "k", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], "/", 
          RowBox[{"w", "[", "k", "]"}]}], "]"}], 
        RowBox[{"Log", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "\[IndentingNewLine]", "-", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", 
           RowBox[{"w", "[", "k", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}], "3"]}], "+", 
          RowBox[{
           RowBox[{"h", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{"8", 
              RowBox[{"w", "[", "k", "]"}]}], "+", 
             RowBox[{"6", 
              SuperscriptBox[
               RowBox[{"w", "[", "k", "]"}], "3"]}]}], ")"}]}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h", "[", "k", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"w", "[", "k", "]"}], "2"]}]], 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          RowBox[{"1", "-", 
           RowBox[{"1", "/", 
            RowBox[{"w", "[", "k", "]"}]}]}]}], "]"}]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"6", 
           RowBox[{"w", "[", "k", "]"}]}], "+", 
          RowBox[{"6", 
           SuperscriptBox[
            RowBox[{"w", "[", "k", "]"}], "2"]}], "+", 
          RowBox[{"4", 
           SuperscriptBox[
            RowBox[{"w", "[", "k", "]"}], "3"]}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"w", "[", "k", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"w", "[", "k", "]"}], "]"}]}], "\[IndentingNewLine]", "+", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"w", "[", "k", "]"}]}], ")"}], "4"], "-", 
          RowBox[{"3", 
           SuperscriptBox[
            RowBox[{"h", "[", "k", "]"}], "3"], 
           RowBox[{"w", "[", "k", "]"}]}], "-", 
          RowBox[{
           RowBox[{"h", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"5", 
              RowBox[{"w", "[", "k", "]"}]}]}], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"w", "[", "k", "]"}]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"h", "[", "k", "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"7", 
              SuperscriptBox[
               RowBox[{"w", "[", "k", "]"}], "2"]}]}], ")"}]}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"h", "[", "k", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", "[", "k", "]"}], "-", 
            RowBox[{"w", "[", "k", "]"}]}], ")"}]}]], 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{
          RowBox[{"h", "[", "k", "]"}], ",", 
          RowBox[{"w", "[", "k", "]"}]}], "]"}]}], "+", 
       RowBox[{"G\[Xi]", "[", 
        RowBox[{"w", "[", "k", "]"}], "]"}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"w", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"h", "[", "x_", "]"}], "\[RuleDelayed]", 
       RowBox[{"SetPrecision", "[", 
        RowBox[{
         FractionBox[
          SuperscriptBox["mHp", "2"], 
          SuperscriptBox[
           RowBox[{"mh", "[", "x", "]"}], "2"]], ",", "50"}], "]"}]}]}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182441013811*^9, 3.800182458478478*^9}, {3.8001825248680525`*^9, 
   3.8001827919024363`*^9}, {3.800182822277143*^9, 3.8001830105089436`*^9}, {
   3.800183246327523*^9, 3.800183247328679*^9}, {3.800184149408285*^9, 
   3.8001841547729416`*^9}, {3.800381028851209*^9, 3.8003810494948597`*^9}, {
   3.800381105896858*^9, 3.800381108754851*^9}, {3.8013391098013716`*^9, 
   3.8013391106620207`*^9}, {3.8013391541191053`*^9, 3.801339157107849*^9}, 
   3.801344546887469*^9, {3.8014085713786783`*^9, 3.8014085923626575`*^9}, {
   3.8015110546406317`*^9, 3.8015110563972178`*^9}, 3.8056014497488346`*^9, {
   3.807646433235151*^9, 3.8076464527528057`*^9}, {3.8097204303616524`*^9, 
   3.8097204602906866`*^9}, {3.809827368182856*^9, 3.809827369613847*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"5feb91e8-e4a9-4a7c-9d1f-a9efbb257759"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq. (38)",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubsuperscriptBox["\[Delta]", "kite", "NC"]}], TraditionalForm]],
  ExpressionUUID->"7ca02805-233b-49e3-8096-996652436f3f"],
 ": neutral-current kite contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
   3.800182192120495*^9, 3.800182203219565*^9}, {3.8013460807650247`*^9, 
   3.8013460836670246`*^9}, {3.8013543217713585`*^9, 3.801354321772365*^9}, {
   3.809720404940596*^9, 3.809720428105669*^9}, 3.809720566748764*^9, {
   3.8097209200805273`*^9, 
   3.809720939851474*^9}},ExpressionUUID->"32ff115b-ba60-4190-b1ac-\
b9957f545375"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]KNC", "[", "k_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"$MaxExtraPrecision", "=", "100"}], ",", 
       RowBox[{"$MinPrecision", "=", "50"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"QfEM", "[", "\"\<l\>\"", "]"}]}], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Qw", "[", "\"\<l\>\"", "]"}], "2"], "-", "1"}], ")"}]}], 
         RowBox[{"8", " ", 
          SuperscriptBox["SW", "2"], 
          SuperscriptBox["CW", "2"]}]], 
        RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
         RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
        RowBox[{"q", "[", 
         RowBox[{"k", ",", "1"}], "]"}], 
        FractionBox["1", 
         SuperscriptBox["z", "3"]], 
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", 
          RowBox[{
           FractionBox[
            SuperscriptBox["\[Pi]", "2"], "6"], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"4", "z"}]}], ")"}]}], "-", 
          RowBox[{"2", 
           SuperscriptBox["z", "2"], 
           RowBox[{"Log", "[", "z", "]"}]}], "+", 
          RowBox[{
           FractionBox[
            RowBox[{"1", "-", 
             RowBox[{"4", "z"}]}], "2"], 
           SuperscriptBox[
            RowBox[{"Log", "[", "z", "]"}], "2"]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"4", "z"}], "+", 
             SuperscriptBox["z", "2"]}], ")"}], 
           RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}]}], "]"}]}], "+", 
          RowBox[{
           FractionBox[
            RowBox[{"1", "-", 
             RowBox[{"6", "z"}], "+", 
             RowBox[{"8", 
              SuperscriptBox["z", "2"]}]}], "2"], 
           RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]}], 
         "\[IndentingNewLine]", ")"}]}], "+", "\[IndentingNewLine]", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Qw", "[", "\"\<l\>\"", "]"}], "2"], "+", "1"}], ")"}]}], 
         RowBox[{"24", " ", 
          SuperscriptBox["SW", "2"], 
          SuperscriptBox["CW", "2"]}]], 
        RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
         RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
        RowBox[{"q", "[", 
         RowBox[{"k", ",", "1"}], "]"}], 
        FractionBox["1", "z"], 
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"2", "z", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"4", "z"}]}], ")"}]}], "+", 
          RowBox[{
           FractionBox[
            SuperscriptBox["\[Pi]", "2"], "3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", 
              SuperscriptBox["z", "2"]}], "+", 
             RowBox[{"4", 
              SuperscriptBox["z", "3"]}]}], ")"}]}], "-", 
          RowBox[{"2", "z", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"4", "z"}]}], ")"}], 
           RowBox[{"Log", "[", "z", "]"}]}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"3", 
              SuperscriptBox["z", "2"]}], "-", 
             RowBox[{"4", 
              SuperscriptBox["z", "3"]}]}], ")"}], 
           RowBox[{"PolyLog", "[", 
            RowBox[{"2", ",", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "z"}], "-", 
             RowBox[{"8", 
              SuperscriptBox["z", "2"]}]}], ")"}], 
           RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]}], 
         "\[IndentingNewLine]", ")"}]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"z", "\[RuleDelayed]", 
        RowBox[{"SetPrecision", "[", 
         RowBox[{
          FractionBox[
           SuperscriptBox[
            RowBox[{"masses", "[", "\"\<Z\>\"", "]"}], "2"], 
           SuperscriptBox[
            RowBox[{"mh", "[", "k", "]"}], "2"]], ",", "50"}], "]"}]}], 
       "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097212585506773`*^9, 3.809721299879694*^9}, {
  3.809721383424017*^9, 3.8097213859979973`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"c469f2b9-b43d-4c75-b5ba-80c723680d40"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eqs. (39, 40)",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubsuperscriptBox["\[Delta]", "kite", "CC"]}], TraditionalForm]],
  ExpressionUUID->"52351ebb-5825-4742-b13b-7e462450397e"],
 ": charged-current kite contribution"
}], "Subsubsection",
 CellChangeTimes->{{3.800180892668498*^9, 3.800180919177822*^9}, {
   3.800182192120495*^9, 3.800182203219565*^9}, {3.8013460807650247`*^9, 
   3.8013460836670246`*^9}, {3.8013543217713585`*^9, 3.801354321772365*^9}, {
   3.809720404940596*^9, 3.809720428105669*^9}, 3.809720566748764*^9, {
   3.8097209200805273`*^9, 
   3.809720961898527*^9}},ExpressionUUID->"f9ea36f2-cec5-4872-8600-\
5aeb905db70e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]KCC", "[", "k_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"$MaxExtraPrecision", "=", "100"}], ",", 
       RowBox[{"$MinPrecision", "=", "50"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"T3", "[", "\"\<l\>\"", "]"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["SW", "2"]}]], 
       RowBox[{"Cf\[ImaginaryI]\[Gamma]5", "[", 
        RowBox[{"k", ",", "\"\<l\>\""}], "]"}], 
       RowBox[{"q", "[", 
        RowBox[{"k", ",", "1"}], "]"}], 
       RowBox[{"(", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"2", 
            SuperscriptBox["\[Pi]", "2"]}], "9"], "w", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"4", "w"}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["2", "3"], 
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"8", "w"}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["16", "3"], 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], 
          RowBox[{"Log", "[", "w", "]"}]}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{"2", "w"}], "-", 
              RowBox[{"6", 
               SuperscriptBox["w", "3"]}], "-", 
              RowBox[{"8", 
               SuperscriptBox["w", "4"]}]}], ")"}]}], 
           RowBox[{"3", 
            SuperscriptBox["w", "2"]}]], 
          RowBox[{"PolyLog", "[", 
           RowBox[{"2", ",", 
            RowBox[{"1", "-", 
             FractionBox["1", "w"]}]}], "]"}]}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", "w"}]}], ")"}], 
            RowBox[{"(", 
             RowBox[{"3", "-", 
              RowBox[{"10", "w"}], "+", 
              SuperscriptBox["w", "2"]}], ")"}]}], 
           RowBox[{"3", 
            SuperscriptBox["w", "2"]}]], 
          RowBox[{"\[CapitalPhi]", "[", "w", "]"}]}], "+", 
         RowBox[{"F\[Xi]", "[", "w", "]"}], "-", 
         RowBox[{"G\[Xi]", "[", "w", "]"}]}], "\[IndentingNewLine]", ")"}]}], 
      "/.", 
      RowBox[{"{", 
       RowBox[{"w", "\[RuleDelayed]", 
        RowBox[{"SetPrecision", "[", 
         RowBox[{
          FractionBox[
           SuperscriptBox[
            RowBox[{"masses", "[", "\"\<W\>\"", "]"}], "2"], 
           SuperscriptBox[
            RowBox[{"mh", "[", "k", "]"}], "2"]], ",", "50"}], "]"}]}], 
       "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8001809301217995`*^9, 3.8001810190535374`*^9}, {
   3.8001810574297466`*^9, 3.800181148233914*^9}, 3.8001813672144165`*^9, {
   3.800182441013811*^9, 3.800182458478478*^9}, {3.8001825248680525`*^9, 
   3.8001827919024363`*^9}, {3.800182822277143*^9, 3.8001830105089436`*^9}, {
   3.800183246327523*^9, 3.800183247328679*^9}, {3.800184149408285*^9, 
   3.8001841547729416`*^9}, {3.800381028851209*^9, 3.8003810494948597`*^9}, {
   3.800381105896858*^9, 3.800381108754851*^9}, {3.8013391098013716`*^9, 
   3.8013391106620207`*^9}, {3.8013391541191053`*^9, 3.801339157107849*^9}, 
   3.801344546887469*^9, 3.801355266652813*^9, {3.8013553046946936`*^9, 
   3.8013555855660763`*^9}, {3.8013562336772385`*^9, 
   3.8013562517027636`*^9}, {3.8013565619031963`*^9, 3.8013565729357247`*^9}, 
   3.801356768090451*^9, {3.801360200836999*^9, 3.8013602023779974`*^9}, {
   3.8014086388526554`*^9, 3.801408657797676*^9}, {3.8014331351794033`*^9, 
   3.80143313521673*^9}, {3.8014332233692203`*^9, 3.8014332259450493`*^9}, {
   3.801433291122732*^9, 3.8014333459936805`*^9}, {3.8014335261286216`*^9, 
   3.8014338443706074`*^9}, {3.8014339627896533`*^9, 
   3.8014339967111044`*^9}, {3.801434034679355*^9, 3.801434038498243*^9}, {
   3.8014340752544737`*^9, 3.801434359861632*^9}, 3.8015016096691046`*^9, {
   3.801505568752762*^9, 3.8015055699963098`*^9}, {3.8015061342433405`*^9, 
   3.801506135288024*^9}, {3.801506201488016*^9, 3.801506225235835*^9}, {
   3.8015138003904195`*^9, 3.8015138053534355`*^9}, 3.8056014523723345`*^9, {
   3.807560788156821*^9, 3.807560796181097*^9}, {3.8075609370872154`*^9, 
   3.807560946565194*^9}, 3.80756100016998*^9, {3.807561070106315*^9, 
   3.8075610727763233`*^9}, {3.8076447868862486`*^9, 3.8076447994025927`*^9}, 
   3.8076449007988644`*^9, {3.8097213226125727`*^9, 3.8097213392084265`*^9}, {
   3.809721370523972*^9, 3.809721373592017*^9}, 3.8098272898791485`*^9},
 CellLabel->"In[42]:=",ExpressionUUID->"4ac54ca6-df78-4c2b-a94a-a70ab1adcb8e"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
full result for the gauge-invariant electron edm in the C2HDM\
\>", "Subsection",
 CellChangeTimes->{{3.809720985847554*^9, 
  3.809720996480591*^9}},ExpressionUUID->"94031006-f51b-4462-8f68-\
12b39bcf2d00"],

Cell["eq. (41)", "Item",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.8097223893204737`*^9, 
  3.809722389321479*^9}},ExpressionUUID->"93b29dbf-06a0-4aa0-9223-\
b91f791db37d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"deOvere", ":=", 
   RowBox[{
    RowBox[{"deOverePrefactor", " ", 
     RowBox[{"Sum", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Delta]fEMtop", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]fEMbottom", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]fEMtau", "[", "k", "]"}], "+", 
          "\[IndentingNewLine]", 
          RowBox[{"\[Delta]fNCtop", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]fNCbottom", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]fNCtau", "[", "k", "]"}]}], ")"}], "+", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Delta]HEM", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]HNC", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]HCC", "[", "k", "]"}]}], ")"}], "+", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Delta]WEM", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]WNC", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]WCC", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]KNC", "[", "k", "]"}], "+", 
          RowBox[{"\[Delta]KCC", "[", "k", "]"}]}], ")"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}], "/.", 
    RowBox[{"\[Xi]", "\[Rule]", "1"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097221195682282`*^9, 3.809722332033928*^9}, {
   3.8097223641024475`*^9, 3.8097223648494473`*^9}, {3.8097275853959227`*^9, 
   3.8097275865769224`*^9}, 3.8100531842731543`*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"b9f5d905-c94f-4408-b289-db582b97f09a"],

Cell["to demonstrate gauge invariance", "Item",
 CellChangeTimes->{{3.8097276199320188`*^9, 
  3.8097276299500446`*^9}},ExpressionUUID->"e87b407e-3f1a-4e9f-89af-\
56c8d719dd85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"deOvere\[LetterSpace]\[Xi]", ":=", 
   RowBox[{"deOverePrefactor", " ", 
    RowBox[{"Sum", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Delta]fEMtop", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]fEMbottom", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]fEMtau", "[", "k", "]"}], "+", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Delta]fNCtop", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]fNCbottom", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]fNCtau", "[", "k", "]"}]}], ")"}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Delta]HEM", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]HNC", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]HCC", "[", "k", "]"}]}], ")"}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Delta]WEM", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]WNC", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]WCC", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]KNC", "[", "k", "]"}], "+", 
         RowBox[{"\[Delta]KCC", "[", "k", "]"}]}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "3"}], "}"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097276132282524`*^9, 3.809727617349019*^9}, {
   3.809808259993703*^9, 3.8098082763487053`*^9}, {3.809808481671304*^9, 
   3.809808482415326*^9}, {3.8098085361390905`*^9, 3.8098085369852004`*^9}, {
   3.8098270945436373`*^9, 3.809827160010638*^9}, {3.8098273269778676`*^9, 
   3.8098273360978465`*^9}, {3.809827385213966*^9, 3.8098273880729656`*^9}, {
   3.8100522180326624`*^9, 3.810052240720782*^9}, 3.810053185763131*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"035b469f-ffe7-463d-9213-1ca54d4d0b62"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
example usage (i.e. how to implement the convention of the paper)\
\>", "Subsection",
 CellChangeTimes->{{3.8097147907647295`*^9, 3.809714792097725*^9}, {
  3.809745339092577*^9, 
  3.8097453462936106`*^9}},ExpressionUUID->"843da4d7-aa30-46a2-b720-\
5c57128b1944"],

Cell[CellGroupData[{

Cell["\<\
In the convention of the paper (see appendix), the free parameters:\
\>", "Item",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.809722389962474*^9, 3.8097223942134767`*^9}, {3.809722495921501*^9, 
  3.8097225272115507`*^9}, {3.809875283705552*^9, 
  3.809875284126605*^9}},ExpressionUUID->"84e987b5-6122-4701-be3d-\
8540e1acbc54"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  SubscriptBox["m", "1"]],ExpressionUUID->
  "79c93337-3811-4dfd-bc9d-f61c32f38853"],
 "=125 GeV, v=246 GeV, \[Zeta]=0"
}], "Subitem",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.809722389962474*^9, 3.8097223933754516`*^9}, {3.8097225305255613`*^9, 
  3.809722551890806*^9}, {3.8097250769222994`*^9, 
  3.8097250769222994`*^9}},ExpressionUUID->"1fb1b57c-86af-4310-8d93-\
52156b86a839"],

Cell[TextData[{
 "choose values for tan[\[Beta]] \[Congruent] ",
 Cell[BoxData[
  FormBox["t\[Beta]", TraditionalForm]], "Item",ExpressionUUID->
  "becf3d66-d9a0-4e16-8bb0-c608973cdf31"],
 ", Im[\[Lambda][5]], Z[3], Z[4], Re[Z[5]], Re[Z[6]]"
}], "Subitem",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.809722389962474*^9, 3.8097223933754516`*^9}, {3.8097225305255613`*^9, 
  3.809722551890806*^9}, {3.8097250776343513`*^9, 3.809725125302503*^9}, {
  3.8097273000020695`*^9, 3.8097273046111403`*^9}, {3.809875300492552*^9, 
  3.8098753004955516`*^9}, {3.8098754138190985`*^9, 
  3.8098754154820814`*^9}},ExpressionUUID->"36979556-4616-4df4-a78a-\
82a88061617d"],

Cell["\<\
Then solve for Y[2], Im[Z[5]], Im[Z[6]], Re[Z[7]], Im[Z[7]], Z[1] to compute \
result\
\>", "Subitem",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.809722389962474*^9, 3.8097223933754516`*^9}, {3.8097225305255613`*^9, 
  3.809722551890806*^9}, {3.8097250776343513`*^9, 3.809725125302503*^9}, {
  3.8097273000020695`*^9, 3.8097273046111403`*^9}, {3.8098753013675547`*^9, 
  3.8098753556216106`*^9}, {3.809875423220129*^9, 
  3.80987543405313*^9}},ExpressionUUID->"c9ef69a6-8e9b-4a32-9854-\
3630a4bc16de"],

Cell["also solve for Z[2] for completeness", "Subsubitem",
 CellChangeTimes->{{3.8097222693772717`*^9, 3.809722273097252*^9}, {
  3.809722389962474*^9, 3.8097223933754516`*^9}, {3.8097225305255613`*^9, 
  3.809722551890806*^9}, {3.8097250776343513`*^9, 3.809725125302503*^9}, {
  3.8097273000020695`*^9, 3.8097273046111403`*^9}, {3.8098753013675547`*^9, 
  3.809875365806635*^9}, {3.809875438263089*^9, 
  3.809875439036129*^9}},ExpressionUUID->"b510c603-b184-427e-ba81-\
aa06601d300f"]
}, Open  ]],

Cell["the benchmark of eqs. (66, 67)", "Item",
 CellChangeTimes->{{3.8097272417450876`*^9, 
  3.8097272657180867`*^9}},ExpressionUUID->"edc63a24-279e-4170-accc-\
dbf1506dbc38"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"benchmarkSub", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v", "\[Rule]", "246"}], ",", 
     RowBox[{"mHp", "\[Rule]", "420"}], ",", 
     RowBox[{
      RowBox[{"Im", "@", 
       RowBox[{"\[Lambda]", "[", "5", "]"}]}], "\[Rule]", "0.01"}], ",", 
     RowBox[{
      RowBox[{"Re", "@", 
       RowBox[{"Z", "[", "5", "]"}]}], "\[Rule]", 
      RowBox[{"-", "1.25"}]}], ",", 
     RowBox[{
      RowBox[{"Z", "[", "3", "]"}], "\[Rule]", "2"}], ",", 
     RowBox[{
      RowBox[{"Z", "[", "4", "]"}], "\[Rule]", 
      RowBox[{"-", "0.45"}]}], ",", 
     RowBox[{
      RowBox[{"Re", "@", 
       RowBox[{"Z", "[", "6", "]"}]}], "\[Rule]", 
      RowBox[{"-", "0.001"}]}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{"e", ".", "g", "."}], " ", "*)"}], " ", 
     RowBox[{"t\[Beta]", "\[Rule]", "12"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097263882731357`*^9, 3.8097264336771355`*^9}, {
   3.8097269960312138`*^9, 3.8097270019492426`*^9}, {3.8097271200998707`*^9, 
   3.809727129720056*^9}, 3.809727163645059*^9, {3.8098278091001754`*^9, 
   3.8098278091511707`*^9}, {3.8098280514408555`*^9, 3.809828053191109*^9}, {
   3.8098285058150015`*^9, 3.8098285058910027`*^9}, {3.8098288718635893`*^9, 
   3.8098288720855703`*^9}, {3.8098289123641605`*^9, 
   3.8098289125451365`*^9}, {3.809829038875602*^9, 3.8098290392636037`*^9}, {
   3.8098716529975824`*^9, 3.8098716530415583`*^9}, {3.80987208850008*^9, 
   3.8098720895940933`*^9}, {3.8098723893556323`*^9, 3.809872389550659*^9}, {
   3.8098725829979825`*^9, 3.8098725830770035`*^9}, {3.809874938479847*^9, 
   3.8098749385298185`*^9}, {3.8098755103282294`*^9, 
   3.8098755103712296`*^9}, {3.809876797812323*^9, 3.809876800068303*^9}, {
   3.809877211173858*^9, 3.809877211232835*^9}, {3.809883861735997*^9, 
   3.809883861811968*^9}, {3.809885068907981*^9, 3.8098850689679556`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"6405215b-34f3-4892-a767-482cca196e1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"complexVars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"q", "[", 
      RowBox[{"2", ",", "2"}], "]"}], ",", 
     RowBox[{"q", "[", 
      RowBox[{"3", ",", "2"}], "]"}], ",", 
     RowBox[{"Z", "[", "5", "]"}], ",", 
     RowBox[{"Z", "[", "6", "]"}], ",", 
     RowBox[{"Z", "[", "7", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097233759753323`*^9, 3.8097233785303335`*^9}, {
  3.8097270710440755`*^9, 3.809727071341095*^9}, {3.8097332599982576`*^9, 
  3.8097333974859858`*^9}, {3.809808325326606*^9, 3.80980836841728*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"4e51624e-3adc-4acd-ad57-9baa2992ed2f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Y[2] is determined from the equation ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", 
    SuperscriptBox["H", "+"], "2"], TraditionalForm]],ExpressionUUID->
  "2e15d582-fe87-4aa8-baf4-9a925e44c42a"],
 "=Y[2] + ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"Z", "[", "3", "]"}], " ", 
    SuperscriptBox["v", "2"]}], TraditionalForm]],ExpressionUUID->
  "b7272e9c-0fe3-4190-b020-17a34e63b7d5"],
 " written above eq. (5)"
}], "Subsubsection",
 CellChangeTimes->{{3.809725478801839*^9, 
  3.8097255586445503`*^9}},ExpressionUUID->"873be640-5e74-421c-ade7-\
a58df44baa67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Y2sub", "=", 
   RowBox[{
    RowBox[{"Y", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     SuperscriptBox["mHp", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"Z", "[", "3", "]"}], 
      SuperscriptBox["v", "2"]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097255374148026`*^9, 3.8097255824140797`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"0ea934a7-5c51-48a9-97eb-f88ef47da092"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The remaining terms in the mass matrix, Im[Z[5]] and Im[Z[6]], are given by \
eq. (92) in the appendix\
\>", "Subsubsection",
 CellChangeTimes->{{3.8097250305043674`*^9, 3.809725061824369*^9}, {
  3.809725134933509*^9, 3.809725192957369*^9}, {3.8097321470869474`*^9, 
  3.8097321470869474`*^9}, {3.809875527036072*^9, 
  3.809875529506071*^9}},ExpressionUUID->"7e051f07-8fbe-4bab-9703-\
2514b815a40b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImZ56sub", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Im", "@", 
         RowBox[{"Z", "[", "5", "]"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"2", "\[Beta]"}], "]"}], 
         RowBox[{"Im", "[", 
          RowBox[{"\[Lambda]", "[", "5", "]"}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Im", "@", 
         RowBox[{"Z", "[", "6", "]"}]}], "\[Rule]", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "\[Beta]"}], "]"}], 
         RowBox[{"Im", "[", 
          RowBox[{"\[Lambda]", "[", "5", "]"}], "]"}]}]}]}], 
      "\[IndentingNewLine]", "}"}], "/.", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"ArcTan", "[", "t\[Beta]", "]"}]}]}], "//", "TrigFactor"}], "//",
    "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.809725206749315*^9, 3.809725345784556*^9}, {
  3.809725414300559*^9, 3.80972541857553*^9}, {3.8097257854239397`*^9, 
  3.809725785569955*^9}, {3.8098287293398256`*^9, 3.809828757756822*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"405ab817-398f-4584-a795-8db8dd662190"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"Z", "[", "5", "]"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["t\[Beta]", "2"]}], ")"}], " ", 
       RowBox[{"Im", "[", 
        RowBox[{"\[Lambda]", "[", "5", "]"}], "]"}]}], 
      RowBox[{"1", "+", 
       SuperscriptBox["t\[Beta]", "2"]}]]}]}], ",", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"Z", "[", "6", "]"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"t\[Beta]", " ", 
      RowBox[{"Im", "[", 
       RowBox[{"\[Lambda]", "[", "5", "]"}], "]"}]}], 
     RowBox[{"1", "+", 
      SuperscriptBox["t\[Beta]", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8097257858674455`*^9, 3.809725790951367*^9}, 
   3.809726919400565*^9, 3.8097976640615597`*^9, 3.8098079003328342`*^9, 
   3.8098285204892426`*^9, {3.809828746208825*^9, 3.809828758067792*^9}, 
   3.8098713074586525`*^9, 3.8098718972786913`*^9, 3.8098720023473997`*^9, 
   3.809872091358081*^9, 3.809872319846774*^9, 3.8098723939566326`*^9, 
   3.8098755158306284`*^9, 3.8098767299789495`*^9, 3.8098768022383256`*^9, 
   3.8098772149468346`*^9, 3.809883865850968*^9, 3.809885072248019*^9, 
   3.8100520336741495`*^9, 3.810052259610531*^9, 3.810052940930971*^9, {
   3.810053208799413*^9, 3.81005322488914*^9}, 3.8100640789121227`*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"d9aff8e0-32c4-42af-a361-4ba978f677f2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalM]sq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["v", "2"], 
      RowBox[{"(", GridBox[{
         {
          RowBox[{"Z", "[", "1", "]"}], 
          RowBox[{"Re", "@", 
           RowBox[{"Z", "[", "6", "]"}]}], 
          RowBox[{"-", 
           RowBox[{"Im", "@", 
            RowBox[{"Z", "[", "6", "]"}]}]}]},
         {
          RowBox[{"Re", "@", 
           RowBox[{"Z", "[", "6", "]"}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"Y", "[", "2", "]"}], "/", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Z", "[", "3", "]"}], "+", 
              RowBox[{"Z", "[", "4", "]"}], "+", 
              RowBox[{"Re", "@", 
               RowBox[{"Z", "[", "5", "]"}]}]}], ")"}]}]}], 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], 
           RowBox[{"Im", "@", 
            RowBox[{"Z", "[", "5", "]"}]}]}]},
         {
          RowBox[{"-", 
           RowBox[{"Im", "@", 
            RowBox[{"Z", "[", "6", "]"}]}]}], 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], 
           RowBox[{"Im", "@", 
            RowBox[{"Z", "[", "5", "]"}]}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"Y", "[", "2", "]"}], "/", 
            SuperscriptBox["v", "2"]}], "+", 
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Z", "[", "3", "]"}], "+", 
              RowBox[{"Z", "[", "4", "]"}], "-", 
              RowBox[{"Re", "@", 
               RowBox[{"Z", "[", "5", "]"}]}]}], ")"}]}]}]}
        }], ")"}]}], "/.", "Y2sub"}], "/.", "ImZ56sub"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097253940135603`*^9, 3.8097254651415453`*^9}, {
   3.8097256087944045`*^9, 3.809725688115984*^9}, 3.8097258210039473`*^9, 
   3.80972638246704*^9, {3.809726612981868*^9, 3.8097266150218573`*^9}, 
   3.8097269136507053`*^9},
 CellLabel->"In[49]:=",ExpressionUUID->"3b7651ef-8ca6-4278-90e1-c5cf84747086"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Z[1] will be determined (numerically) by fixing ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "1"], TraditionalForm]],ExpressionUUID->
  "ada251c3-ff7a-4475-accc-8d1a6ef5d413"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "h"], TraditionalForm]],ExpressionUUID->
  "0281005f-1ca7-40e4-99a5-548c2ca427a5"],
 " = 125 GeV"
}], "Subsubsection",
 CellChangeTimes->{{3.80972536268853*^9, 3.8097253831565876`*^9}, {
  3.8097255895945807`*^9, 3.809725595517377*^9}, {3.8098761683920536`*^9, 
  3.8098761702327175`*^9}},ExpressionUUID->"859d714e-e4f0-4fd1-bee7-\
b4bfdf98d750"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "@", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"\[ScriptCapitalM]sq", "/.", "benchmarkSub"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8097270176269474`*^9, 3.809727018400972*^9}, {
   3.8097270505279512`*^9, 3.8097270517539206`*^9}, 3.8097271354620323`*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"4630b83f-86e7-46d6-81d4-fa19546cf523"],

Cell[BoxData[
 RowBox[{"Root", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1.0462808086041563`*^9", "+", 
     RowBox[{"1.`", " ", 
      SuperscriptBox["#1", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["#1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "325567.8`"}], "-", 
        RowBox[{"60516.`", " ", 
         RowBox[{"Z", "[", "1", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"1.5170131240458728`*^15", " ", 
      RowBox[{"Z", "[", "1", "]"}]}], "+", 
     RowBox[{"#1", " ", 
      RowBox[{"(", 
       RowBox[{"2.5067961376117344`*^10", "+", 
        RowBox[{"1.97020609848`*^10", " ", 
         RowBox[{"Z", "[", "1", "]"}]}]}], ")"}]}]}], "&"}], ",", "1"}], 
  "]"}]], "Output",
 CellChangeTimes->{
  3.8097270188349576`*^9, 3.809727052283945*^9, {3.8097271359260316`*^9, 
   3.809727139482032*^9}, 3.8097976641650715`*^9, 3.809807900408804*^9, 
   3.8098278120571656`*^9, {3.8098280476659827`*^9, 3.809828054934083*^9}, {
   3.8098285081239767`*^9, 3.8098285212642117`*^9}, 3.809828770390456*^9, 
   3.80982888120713*^9, 3.809828918003155*^9, 3.8098290515525646`*^9, 
   3.8098713075856876`*^9, 3.8098716547047873`*^9, 3.809871897436721*^9, 
   3.8098720024283667`*^9, 3.809872091442055*^9, 3.8098723199537745`*^9, 
   3.809872394084667*^9, 3.809872587692012*^9, 3.809874948513028*^9, 
   3.809875538913411*^9, 3.809876739178296*^9, 3.8098768023003263`*^9, 
   3.809877215032832*^9, 3.809883865927967*^9, 3.8098850722959905`*^9, 
   3.810052033777119*^9, 3.81005225966656*^9, 3.8100529411199427`*^9, {
   3.810053208853413*^9, 3.810053224967143*^9}, 3.810064078963123*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"1a08952a-07d0-40af-950d-98b71694faeb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Z1sub", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Eigenvalues", "[", 
         RowBox[{"\[ScriptCapitalM]sq", "/.", "benchmarkSub"}], "]"}], 
        "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "[", 
       SuperscriptBox["125", "2"], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"Z", "[", "1", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8097257226856794`*^9, 3.8097257318653584`*^9}, {
  3.8097261534349213`*^9, 3.80972615427495*^9}, {3.80972619666037*^9, 
  3.809726215215909*^9}, {3.8097264375461125`*^9, 3.809726453207118*^9}, {
  3.8097265902920923`*^9, 3.8097266784999957`*^9}, {3.809726925827103*^9, 
  3.809726925914095*^9}, {3.8097270041012564`*^9, 3.8097270473189735`*^9}, {
  3.8097270878800774`*^9, 3.8097270880390787`*^9}, {3.8097272223176823`*^9, 
  3.8097272264070625`*^9}, {3.8097977120509005`*^9, 3.809797747090353*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"fae41abb-e659-4019-b46e-dd12c74523c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Z", "[", "1", "]"}], "\[Rule]", "0.2581969555950409`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.809725734508356*^9, {3.8097257972433567`*^9, 3.809725823843813*^9}, 
   3.809726154683922*^9, {3.809726197232375*^9, 3.8097262104323697`*^9}, {
   3.809726440030139*^9, 3.809726454110111*^9}, {3.8097265936580963`*^9, 
   3.8097266180388556`*^9}, {3.809726649960831*^9, 3.80972667885797*^9}, 
   3.809726877914111*^9, {3.8097269195675335`*^9, 3.8097269264230814`*^9}, {
   3.8097270047762437`*^9, 3.8097270478679495`*^9}, {3.8097270812360764`*^9, 
   3.809727094232044*^9}, 3.8097271471540346`*^9, {3.8097272228376875`*^9, 
   3.809727226751062*^9}, 3.809797664205078*^9, {3.809797708723568*^9, 
   3.8097977479984655`*^9}, 3.809807900446805*^9, 3.8098278135431657`*^9, 
   3.809828056252057*^9, 3.8098285213732123`*^9, 3.809828771602456*^9, 
   3.809828881350128*^9, 3.8098289180951347`*^9, 3.809829051629575*^9, 
   3.8098713076346827`*^9, 3.809871655429784*^9, 3.809871897526722*^9, 
   3.809872002498396*^9, 3.8098720915280857`*^9, 3.809872320009803*^9, 
   3.80987239416466*^9, 3.809872587768011*^9, 3.809874948575564*^9, 
   3.8098755408224144`*^9, 3.809876739848296*^9, 3.8098768023553333`*^9, 
   3.8098772150948625`*^9, 3.809883865990961*^9, 3.8098850723280206`*^9, 
   3.810052033823121*^9, 3.8100522597025604`*^9, 3.8100529411949415`*^9, {
   3.8100532088984137`*^9, 3.81005322501717*^9}, 3.8100640789951534`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"755467cd-f2a3-4e7f-b479-a81a04b7942f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["compute rotation matrix, physical masses", "Subsubsection",
 CellChangeTimes->{{3.8098762202321014`*^9, 3.8098762729442787`*^9}, {
  3.810052530427991*^9, 
  3.810052535163374*^9}},ExpressionUUID->"a2c08c17-0f1c-481e-aea3-\
0a111740c769"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mhsq", ",", "R"}], "}"}], "=", 
  RowBox[{"Eigensystem", "[", 
   RowBox[{
    RowBox[{"\[ScriptCapitalM]sq", "/.", "benchmarkSub"}], "/.", "Z1sub"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8097336107543693`*^9, 3.8097336417470155`*^9}, {
  3.809733672921998*^9, 3.809733693547083*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"ac65dd78-9e5e-43c4-b3c7-fa6be879fd92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "200607.59083243427`", ",", "124960.2561323554`", ",", 
     "15624.999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00027202863045997205`"}], ",", "0.003944952264107828`",
        ",", "0.9999921816454658`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000551679014558678`", ",", 
       RowBox[{"-", "0.9999920658792313`"}], ",", "0.0039451018810721`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.9999998108253267`", ",", "0.0005527478819982806`", ",", 
       "0.00026985012477442113`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.809733614251171*^9, 3.8097336420989976`*^9}, 
   3.809733694027075*^9, 3.809797664275071*^9, 3.8097977026636057`*^9, 
   3.8098079004928055`*^9, 3.8098278190661416`*^9, 3.8098280603190823`*^9, 
   3.8098285215657225`*^9, 3.809828778214461*^9, 3.8098288815361233`*^9, 
   3.80982891828316*^9, 3.8098290518215666`*^9, 3.8098713078776803`*^9, 
   3.8098716591050577`*^9, 3.80987189772069*^9, 3.8098720025963964`*^9, 
   3.8098720916560802`*^9, 3.8098723201478033`*^9, 3.8098723943446603`*^9, 
   3.8098725879620113`*^9, 3.8098749487433834`*^9, 3.8098767413942094`*^9, 
   3.8098768024063253`*^9, 3.8098772151468334`*^9, 3.8098838660699663`*^9, 
   3.809885072368991*^9, 3.8100520338611193`*^9, 3.810052259756564*^9, 
   3.8100529412679443`*^9, {3.8100532089484158`*^9, 3.8100532250721416`*^9}, 
   3.810064079046152*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"55f79c0d-60dc-4e4c-921d-bd083f917c3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mh", "[", "1", "]"}], ",", 
    RowBox[{"mh", "[", "2", "]"}], ",", 
    RowBox[{"mh", "[", "3", "]"}]}], "}"}], "=", 
  SqrtBox["mhsq"]}]], "Input",
 CellChangeTimes->{{3.809733698732134*^9, 3.8097337089371557`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"a5ef0625-6f0a-49e7-a588-655fbffd6f82"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "447.89238755803194`", ",", "353.4971798082064`", ",", 
   "124.99999999999999`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8097337093691297`*^9, 3.8097976643250713`*^9, 3.8098079005448065`*^9, 
   3.8098278210081716`*^9, 3.809828060921087*^9, 3.8098285216447215`*^9, 
   3.809828779606432*^9, 3.809828881635124*^9, 3.8098289183601646`*^9, 
   3.80982905189857*^9, 3.8098713079356527`*^9, 3.8098716598134675`*^9, 
   3.809871897825715*^9, 3.8098720026633964`*^9, 3.809872091741079*^9, 
   3.8098723202048035`*^9, 3.809872394433662*^9, 3.8098725879720135`*^9, 
   3.809874948812286*^9, 3.8098767428363094`*^9, 3.809876802457326*^9, 
   3.8098772151978617`*^9, 3.809883866132968*^9, 3.8098850723799906`*^9, 
   3.8100520338991184`*^9, 3.8100522598025556`*^9, 3.810052941334967*^9, {
   3.8100532090084143`*^9, 3.810053225137142*^9}, 3.810064079086152*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"04b379dd-16da-4ef7-ae38-dc5b40dbd467"]
}, Open  ]],

Cell[TextData[{
 "one could exchange the rows here if desired so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[ScriptCapitalM]", "diag", "2"], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["m", "1", "2"], ",", " ", 
      SubsuperscriptBox["m", "2", "2"], ",", " ", 
      SubsuperscriptBox["m", "3", "2"]}], "}"}]}], TraditionalForm]],
  ExpressionUUID->"f2f2b38f-c81e-4b92-83ea-1923a250b3d1"]
}], "Item",
 CellChangeTimes->{{3.809876278265603*^9, 
  3.8098763395797834`*^9}},ExpressionUUID->"92f2a714-98f2-4712-bd5d-\
5e46d212b3f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"R", ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[ScriptCapitalM]sq", "/.", "benchmarkSub"}], "/.", "Z1sub"}], 
    ")"}], ".", 
   RowBox[{"R", "\[Transpose]"}]}], "//", "Chop"}]], "Input",
 CellChangeTimes->{{3.80973376895809*^9, 3.8097337823979073`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"937e7131-de8d-425f-b5d1-4b17a03e30e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200607.5908324343`", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "124960.25613235518`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "15625.00000000001`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8097337763249044`*^9, 3.809733782622901*^9}, 
   3.8097976643586016`*^9, 3.8098079005528336`*^9, 3.8098278238871403`*^9, 
   3.8098280630651827`*^9, 3.8098285217427225`*^9, 3.809828781791456*^9, 
   3.8098288817131243`*^9, 3.8098289184381647`*^9, 3.80982905196657*^9, 
   3.8098713079926825`*^9, 3.8098716607950153`*^9, 3.8098718979047194`*^9, 
   3.8098720026733665`*^9, 3.809872091818083*^9, 3.809872320342803*^9, 
   3.8098723945026307`*^9, 3.8098725880370116`*^9, 3.8098749488747883`*^9, 
   3.809876744050335*^9, 3.809876802510298*^9, 3.809877215248831*^9, 
   3.809883866195964*^9, 3.8098850724129915`*^9, 3.8100520339071198`*^9, 
   3.810052259856556*^9, 3.810052941400941*^9, {3.810053209073414*^9, 
   3.810053225203141*^9}, 3.810064079093152*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"5bb1a5b1-4b37-4103-8579-2046ee86c683"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qkSub", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}], "@@@", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Flatten", "/@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"(", GridBox[{
          {
           RowBox[{"q", "[", 
            RowBox[{"1", ",", "1"}], "]"}], 
           RowBox[{"Re", "@", 
            RowBox[{"q", "[", 
             RowBox[{"1", ",", "2"}], "]"}]}], 
           RowBox[{"Im", "@", 
            RowBox[{"q", "[", 
             RowBox[{"1", ",", "2"}], "]"}]}]},
          {
           RowBox[{"q", "[", 
            RowBox[{"2", ",", "1"}], "]"}], 
           RowBox[{"Re", "@", 
            RowBox[{"q", "[", 
             RowBox[{"2", ",", "2"}], "]"}]}], 
           RowBox[{"Im", "@", 
            RowBox[{"q", "[", 
             RowBox[{"2", ",", "2"}], "]"}]}]},
          {
           RowBox[{"q", "[", 
            RowBox[{"3", ",", "1"}], "]"}], 
           RowBox[{"Re", "@", 
            RowBox[{"q", "[", 
             RowBox[{"3", ",", "2"}], "]"}]}], 
           RowBox[{"Im", "@", 
            RowBox[{"q", "[", 
             RowBox[{"3", ",", "2"}], "]"}]}]}
         }], ")"}], ",", "R"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.809733878573001*^9, {3.809734021546748*^9, 3.8097341192539587`*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"c8202ecc-c906-4c00-9a01-7a14f9b035f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", 
    RowBox[{"-", "0.00027202863045997205`"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"q", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    "0.003944952264107828`"}], ",", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"q", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    "0.9999921816454658`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", "0.000551679014558678`"}], 
   ",", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"q", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    RowBox[{"-", "0.9999920658792313`"}]}], ",", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"q", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    "0.0039451018810721`"}], ",", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "\[Rule]", "0.9999998108253267`"}], ",", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"q", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    "0.0005527478819982806`"}], ",", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"q", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "]"}], "\[Rule]", 
    "0.00026985012477442113`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8097340242968836`*^9, 3.809734119576915*^9}, 
   3.8097976643936005`*^9, 3.809807900585806*^9, 3.8098278254261665`*^9, 
   3.8098280636552114`*^9, 3.8098285218277225`*^9, 3.809828782890463*^9, 
   3.8098288818061295`*^9, 3.8098289185171647`*^9, 3.80982905204257*^9, 
   3.809871308048682*^9, 3.8098716625610156`*^9, 3.8098718979967213`*^9, 
   3.809872002743396*^9, 3.8098720919030824`*^9, 3.8098723204498034`*^9, 
   3.80987239458566*^9, 3.809872588106019*^9, 3.809874948928235*^9, 
   3.8098767448063393`*^9, 3.8098768025623255`*^9, 3.809877215299861*^9, 
   3.8098838662719674`*^9, 3.8098850724450207`*^9, 3.810052033946119*^9, 
   3.8100522599195604`*^9, 3.810052941477967*^9, {3.810053209123444*^9, 
   3.810053225266142*^9}, 3.8100640791241245`*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"584c90fc-7701-4ad3-afa9-c5974d8621ca"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solve for Z[2], Z[7]", "Subsubsection",
 CellChangeTimes->{{3.8098759089917507`*^9, 3.8098759206427326`*^9}, {
  3.8098764587654715`*^9, 
  3.8098764591334696`*^9}},ExpressionUUID->"447cfd8b-94a0-45ab-ae9c-\
884f34325272"],

Cell["from eq. (92) in the appendix,", "Item",
 CellChangeTimes->{{3.8098764743373303`*^9, 
  3.8098765093813105`*^9}},ExpressionUUID->"fcdb0f9c-1449-44d8-815f-\
bf0746130a79"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Im", "@", 
    RowBox[{"Z", "[", "7", "]"}]}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"Im", "@", 
     RowBox[{"Z", "[", "6", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.809876511189186*^9, 3.809876517995303*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"4b392941-d5f9-4c4c-b3b4-cbc98d5a960e"],

Cell[TextData[{
 "Starting with eq. (89) in ",
 ButtonBox["arxiv.org/pdf/2001.01430.pdf",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/2001.01430.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/2001.01430.pdf"]
}], "Item",
 CellChangeTimes->{{3.8098743865281425`*^9, 3.8098743954130077`*^9}, {
  3.8098756324445314`*^9, 
  3.8098756528135166`*^9}},ExpressionUUID->"bd31b240-1492-4a9b-83d1-\
dacdbbf625da"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ComplexExpand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Z", "[", "1", "]"}], "-", 
          RowBox[{"Z", "[", "2", "]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Z", "[", 
            RowBox[{"3", ",", "4"}], "]"}], 
           RowBox[{
            RowBox[{"Z", "[", 
             RowBox[{"6", ",", "7"}], "]"}], "\[Conjugate]"}]}], "-", 
          RowBox[{
           RowBox[{"Z", "[", "1", "]"}], 
           RowBox[{
            RowBox[{"Z", "[", "7", "]"}], "\[Conjugate]"}]}], "-", 
          RowBox[{
           RowBox[{"Z", "[", "2", "]"}], 
           RowBox[{
            RowBox[{"Z", "[", "6", "]"}], "\[Conjugate]"}]}], "+", 
          RowBox[{
           RowBox[{
            RowBox[{"Z", "[", "5", "]"}], "\[Conjugate]"}], 
           RowBox[{"Z", "[", 
            RowBox[{"6", ",", "7"}], "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", 
        RowBox[{
         RowBox[{"Z", "[", 
          RowBox[{"6", ",", "7"}], "]"}], "\[Conjugate]"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{"Z", "[", "6", "]"}], "]"}], "2"], "-", 
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{"Z", "[", "7", "]"}], "]"}], "2"]}], ")"}]}]}], "/.", 
      RowBox[{
       RowBox[{"Z", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"Z", "[", "a", "]"}], "+", 
        RowBox[{"Z", "[", "b", "]"}]}]}]}], ",", "complexVars", ",", 
     RowBox[{"TargetFunctions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"Im", "@", 
     RowBox[{"Z", "[", "7", "]"}]}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"Im", "@", 
      RowBox[{"Z", "[", "6", "]"}]}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.809873646189148*^9, 3.8098736850770073`*^9}, 
   3.809873727306511*^9, 3.809873790208147*^9, 3.809874233881033*^9},
 CellLabel->"In[57]:=",ExpressionUUID->"78af7975-0511-4fa3-b046-116daaca9977"],

Cell["\<\
the two equations for the real and imaginary part can be solved for Re[Z[7]] \
and Z[2]\
\>", "Item",
 CellChangeTimes->{{3.809874433132877*^9, 
  3.809874459406386*^9}},ExpressionUUID->"84ac635d-352b-433f-8710-\
08e709740d8a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{"Re", "[", "%", "]"}], ",", "complexVars"}], "]"}], "\[Equal]", 
    "0"}], ",", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{"Im", "[", "%", "]"}], ",", "complexVars"}], "]"}], "\[Equal]", 
    "0"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.8098736862514625`*^9, 3.8098737144333115`*^9}, 
   3.8098737475493793`*^9, {3.809873811105322*^9, 3.8098738233290443`*^9}, {
   3.8098739977002587`*^9, 3.8098740059520197`*^9}, {3.8098740891889143`*^9, 
   3.8098741158415956`*^9}, 3.8098742427200603`*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"f71cf21d-1d21-456f-9add-4e8f111e121e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox[
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "6", "]"}], "]"}], "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "6", "]"}], "]"}], "2"], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "7", "]"}], "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "7", "]"}], "]"}], "3"]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Z", "[", "1", "]"}], "2"]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Z", "[", "2", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "3", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}], " ", 
      RowBox[{"Z", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}], " ", 
      RowBox[{"Z", "[", "3", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "4", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}], " ", 
      RowBox[{"Z", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}], " ", 
      RowBox[{"Z", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Im", "[", 
        RowBox[{"Z", "[", "5", "]"}], "]"}]}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Z", "[", "1", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      RowBox[{"Z", "[", "1", "]"}], " ", 
      RowBox[{"Z", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Z", "[", "2", "]"}], "2"]}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8098736956614275`*^9, 3.809873750739814*^9}, {
   3.8098737927989798`*^9, 3.8098738272285013`*^9}, 3.8098739579559145`*^9, {
   3.8098739993863134`*^9, 3.8098740519391165`*^9}, {3.8098741016903048`*^9, 
   3.8098741183710833`*^9}, 3.8098741777793846`*^9, {3.809874236442895*^9, 
   3.809874254586502*^9}, {3.8098743227817745`*^9, 3.809874324918399*^9}, {
   3.8098744154627857`*^9, 3.8098744211169147`*^9}, 3.809876403008772*^9, {
   3.8098766283329163`*^9, 3.809876646377669*^9}, 3.809876749852195*^9, 
   3.809876802652322*^9, 3.809877215371833*^9, 3.80988386642496*^9, 
   3.8098850724980197`*^9, 3.810052034042119*^9, 3.8100522600065327`*^9, 
   3.81005294164797*^9, {3.810053209189414*^9, 3.810053225353141*^9}, 
   3.8100640791741223`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"e68056d1-57b7-41c0-bf12-5d736b7874f3"]
}, Open  ]],

Cell["\<\
See appendix B of the same paper for a discussion of the special case of the \
first solution\
\>", "Item",
 CellChangeTimes->{{3.809874466958688*^9, 3.8098744924539776`*^9}, {
  3.8098745238117943`*^9, 
  3.8098745371301584`*^9}},ExpressionUUID->"ac842bc1-df0f-432c-a6a5-\
4b7a361138e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "@", 
      RowBox[{"Z", "[", "7", "]"}]}], ",", 
     RowBox[{"Z", "[", "2", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8098738333286552`*^9, 3.8098738343550205`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"56163384-6eac-4a00-b93d-63623094a8bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "6", "]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Z", "[", "2", "]"}], "\[Rule]", 
      RowBox[{"Z", "[", "1", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], "\[Rule]", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Z", "[", "2", "]"}], "\[Rule]", 
      RowBox[{"Z", "[", "1", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", "7", "]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], "2"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "6", "]"}], "]"}], "2"], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "1", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "3", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "4", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Z", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], "3"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "3"], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "6", "]"}], "]"}], "2"], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "1", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "6", "]"}], "]"}], "3"], " ", 
          RowBox[{"Z", "[", "1", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "3", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"Z", "[", "4", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8098738346321144`*^9, 3.809874106284464*^9, 3.809874152026437*^9, 
   3.80987418293123*^9, {3.8098742492227263`*^9, 3.8098742586133947`*^9}, 
   3.8098743260749836`*^9, 3.809874421949645*^9, 3.809876404329797*^9, {
   3.809876629264888*^9, 3.809876647152998*^9}, 3.809876751022805*^9, 
   3.8098768027053213`*^9, 3.809877215420861*^9, 3.809883866508936*^9, 
   3.809885072530021*^9, 3.8100520340831194`*^9, 3.810052260065555*^9, 
   3.810052941704943*^9, {3.810053209232414*^9, 3.810053225419141*^9}, 
   3.8100640792061515`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"58242057-f749-494e-b4ce-ef451a995d83"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Z2ReZ7sub", "=", 
  RowBox[{"FullSimplify", "@", 
   RowBox[{"Last", "[", "%", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8098742876358747`*^9, 3.8098742999038486`*^9}, {
  3.8098766209958878`*^9, 3.8098766425876603`*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"0a2b9ae8-5188-41f8-a937-846b34d6be75"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"Z", "[", "7", "]"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"Z", "[", "6", "]"}], "]"}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Im", "[", 
            RowBox[{"Z", "[", "5", "]"}], "]"}]}], " ", 
          RowBox[{"Re", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Im", "[", 
           RowBox[{"Z", "[", "6", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Re", "[", 
             RowBox[{"Z", "[", "5", "]"}], "]"}], "-", 
            RowBox[{"Z", "[", "1", "]"}], "+", 
            RowBox[{"Z", "[", "3", "]"}], "+", 
            RowBox[{"Z", "[", "4", "]"}]}], ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Im", "[", 
         RowBox[{"Z", "[", "6", "]"}], "]"}], "2"]}]]}]}], ",", 
   RowBox[{
    RowBox[{"Z", "[", "2", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Im", "[", 
          RowBox[{"Z", "[", "5", "]"}], "]"}], "3"], " ", 
        RowBox[{"Re", "[", 
         RowBox[{"Z", "[", "6", "]"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Im", "[", 
          RowBox[{"Z", "[", "6", "]"}], "]"}], "3"]}]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Im", "[", 
        RowBox[{"Z", "[", "5", "]"}], "]"}], " ", 
       RowBox[{"Re", "[", 
        RowBox[{"Z", "[", "6", "]"}], "]"}]}], 
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", "6", "]"}], "]"}]], "+", 
     RowBox[{"Z", "[", "1", "]"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Im", "[", 
         RowBox[{"Z", "[", "5", "]"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Z", "[", "5", "]"}], "]"}], "-", 
         RowBox[{"Z", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "3", "]"}], "+", 
         RowBox[{"Z", "[", "4", "]"}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Im", "[", 
         RowBox[{"Z", "[", "6", "]"}], "]"}], "2"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8098743002842665`*^9, 3.809874328860737*^9}, 
   3.8098764067497964`*^9, {3.8098766231657305`*^9, 3.8098766480340757`*^9}, 
   3.8098767529117727`*^9, 3.8098768027573214`*^9, 3.8098772154718685`*^9, 
   3.8098838671459365`*^9, 3.8098850725609922`*^9, 3.810052034989152*^9, 
   3.8100522608755627`*^9, 3.810052942505966*^9, {3.8100532100508347`*^9, 
   3.810053226381714*^9}, 3.8100640800031233`*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"dd3cd041-e5eb-4570-b282-a2a5c9302de2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z27sub", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{"Z2ReZ7sub", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Im", "@", 
         RowBox[{"Z", "[", "7", "]"}]}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"Im", "@", 
          RowBox[{"Z", "[", "6", "]"}]}]}]}], "}"}]}], "]"}], "/.", 
    "ImZ56sub"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.809876535884661*^9, 3.809876567638506*^9}, 
   3.809876643558205*^9},
 CellLabel->"In[61]:=",ExpressionUUID->"e956700d-f608-41a9-943a-f1e7f500e279"],

Cell[TextData[{
 "For a more compact solution of Z[2], solve the real part of eq. (A29) in \
the case of the softly-broken\[LineSeparator]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[DoubleStruckCapitalZ]", "2"], TraditionalForm]],
  ExpressionUUID->"8a07cdd9-c2da-48fd-8b97-8f0189412bc6"],
 " symmetry"
}], "Item",
 CellChangeTimes->{{3.8098757203527174`*^9, 
  3.809875762252846*^9}},ExpressionUUID->"8e600f6a-c0ca-485d-9414-\
80dfe0edc752"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"0", "\[Equal]", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "2"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", "\[Beta]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Z", "[", "1", "]"}], "-", 
         RowBox[{"Z", "[", "2", "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"2", "\[Beta]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "@", 
          RowBox[{"Z", "[", "6", "]"}]}], "+", 
         RowBox[{"Re", "@", 
          RowBox[{"Z", "[", "7", "]"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{"Z", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.809874806146391*^9, 3.80987486286019*^9}, {
   3.8098750719819584`*^9, 3.8098750834977407`*^9}, 3.809875149300327*^9},
 CellLabel->"In[62]:=",ExpressionUUID->"4b38a561-558e-442c-bfd4-d2bd7d8ed5b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Z", "[", "2", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{"2", " ", "\[Beta]"}], "]"}], " ", 
     RowBox[{"Re", "[", 
      RowBox[{"Z", "[", "6", "]"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{"2", " ", "\[Beta]"}], "]"}], " ", 
     RowBox[{"Re", "[", 
      RowBox[{"Z", "[", "7", "]"}], "]"}]}], "+", 
    RowBox[{"Z", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8098748504280915`*^9, 3.8098748629984016`*^9}, {
   3.809875078506504*^9, 3.809875087191269*^9}, 3.809875149546327*^9, 
   3.809876755501774*^9, 3.8098768028182955`*^9, 3.8098772155308704`*^9, 
   3.8098838672749367`*^9, 3.8098850726000195`*^9, 3.810052035044146*^9, 
   3.810052260957562*^9, 3.810052942616942*^9, {3.8100532101378355`*^9, 
   3.8100532263917403`*^9}, 3.810064080071122*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"46cc565e-3aa4-4006-9211-8875a7b0e5f1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "e"], "/", "e"}], TraditionalForm]],ExpressionUUID->
  "15d8b8b1-e3ab-4460-8471-0fafa8222850"]
}], "Subsubsection",
 CellChangeTimes->{{3.8098760866739297`*^9, 
  3.8098761137462177`*^9}},ExpressionUUID->"fae3c7eb-8da2-4d3c-b894-\
58beeeecfe68"],

Cell["check gauge invariance", "Item",
 CellChangeTimes->{{3.8098727423562675`*^9, 3.8098727634943113`*^9}, {
  3.809878033541132*^9, 
  3.809878038008421*^9}},ExpressionUUID->"477bf317-241b-4b52-8ba6-\
64c15746627d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"deOvere\[LetterSpace]\[Xi]", "/.", 
          RowBox[{"\[Xi]", "\[Rule]", "3"}]}], ",", "complexVars", ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "/.", 
       RowBox[{"specificTypeReplacement", "[", "\"\<Type 2\>\"", "]"}]}], "/.", 
      RowBox[{"\[Beta]", "\[Rule]", 
       RowBox[{"ArcTan", "[", "t\[Beta]", "]"}]}]}], "/.", "Z27sub"}], "/.", 
    "Z1sub"}], "/.", "benchmarkSub"}], "/.", "qkSub"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"deOvere\[LetterSpace]\[Xi]", "/.", 
          RowBox[{"\[Xi]", "\[Rule]", "12"}]}], ",", "complexVars", ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "/.", 
       RowBox[{"specificTypeReplacement", "[", "\"\<Type 2\>\"", "]"}]}], "/.", 
      RowBox[{"\[Beta]", "\[Rule]", 
       RowBox[{"ArcTan", "[", "t\[Beta]", "]"}]}]}], "/.", "Z27sub"}], "/.", 
    "Z1sub"}], "/.", "benchmarkSub"}], "/.", "qkSub"}]}], "Input",
 CellChangeTimes->{{3.8098726072080345`*^9, 3.80987261737601*^9}, {
   3.809872718597208*^9, 3.8098727324842386`*^9}, {3.8098727670842524`*^9, 
   3.809872767218277*^9}, 3.809872808668332*^9, {3.8098765950755224`*^9, 
   3.80987659835876*^9}, {3.809876844934636*^9, 3.809876879682352*^9}, {
   3.8098772358382463`*^9, 3.809877250487833*^9}, 3.8100521760728235`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"8e6d4d58-9a29-476b-b60f-2e8e5b9076da"],

Cell[BoxData[
 RowBox[{"1.416861497222511`*^-29", "+", 
  RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.8098726122919817`*^9, 3.809872619072982*^9}, 
   3.809872735151245*^9, 3.809872771685327*^9, {3.809872803168356*^9, 
   3.809872810994356*^9}, 3.8098749518084517`*^9, 3.8098766003838015`*^9, 
   3.8098766523856745`*^9, 3.8098767593629637`*^9, 3.8098768042458897`*^9, {
   3.809876853679329*^9, 3.809876881271352*^9}, {3.8098772169258394`*^9, 
   3.80987725256744*^9}, 3.8098838686659365`*^9, 3.8098850739782763`*^9, 
   3.810052039875905*^9, {3.810052221172632*^9, 3.810052295670718*^9}, 
   3.810052947445006*^9, {3.810053212442836*^9, 3.8100532278057365`*^9}, 
   3.8100640822611237`*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"976a01a2-9d4a-4796-ac3d-43e556a70509"],

Cell[BoxData[
 RowBox[{"1.416861497212196`*^-29", "+", 
  RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.8098726122919817`*^9, 3.809872619072982*^9}, 
   3.809872735151245*^9, 3.809872771685327*^9, {3.809872803168356*^9, 
   3.809872810994356*^9}, 3.8098749518084517`*^9, 3.8098766003838015`*^9, 
   3.8098766523856745`*^9, 3.8098767593629637`*^9, 3.8098768042458897`*^9, {
   3.809876853679329*^9, 3.809876881271352*^9}, {3.8098772169258394`*^9, 
   3.80987725256744*^9}, 3.8098838686659365`*^9, 3.8098850739782763`*^9, 
   3.810052039875905*^9, {3.810052221172632*^9, 3.810052295670718*^9}, 
   3.810052947445006*^9, {3.810053212442836*^9, 3.8100532278057365`*^9}, 
   3.8100640838561225`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"0f7a4cd3-3fb6-4c1f-8ae1-f6ecf61fac18"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section",
 CellChangeTimes->{{3.8098778438777723`*^9, 3.809877846984959*^9}, 
   3.809878020107915*^9},ExpressionUUID->"c6b79117-9a7b-43f6-ab6a-\
91952681c54b"],

Cell[TextData[{
 " R. Boto, T. V. Fernandes, H. E. Haber, J. C. Rom\[ATilde]o, and J. a. P. \
Silva,",
 ButtonBox[" Phys. Rev. D 101, 055023 (2020)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://journals.aps.org/prd/abstract/10.1103/PhysRevD.101.055023"], 
    None},
  ButtonNote->
   "https://journals.aps.org/prd/abstract/10.1103/PhysRevD.101.055023"],
 ",\n",
 ButtonBox["arXiv:2001.01430 [hep-ph]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2001.01430"], None},
  ButtonNote->"https://arxiv.org/abs/2001.01430"]
}], "Text",
 CellChangeTimes->{{3.809877920109058*^9, 
  3.8098780156269445`*^9}},ExpressionUUID->"1f605d4a-c156-4b43-8b86-\
6a4392569ed8"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{822.4285714285713, 853.7142857142857},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellContext->Notebook,
FrontEndVersion->"12.1 for Microsoft Windows (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"7f3f711e-370f-49c5-9f63-af2538e3db7f"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 175, 3, 53, "Subtitle",ExpressionUUID->"ac6ede36-32ed-4a39-ad73-590cf73ce3b8"],
Cell[CellGroupData[{
Cell[780, 29, 160, 3, 32, "Item",ExpressionUUID->"75a2e040-a9ba-41b2-b6a3-699955f534e5"],
Cell[943, 34, 162, 3, 26, "Subitem",ExpressionUUID->"c41e8437-67a1-4d56-a723-791039720dba"],
Cell[1108, 39, 399, 8, 32, "Item",ExpressionUUID->"ff648a4c-874f-4f51-98b1-4b3b4bce9781"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1544, 52, 177, 3, 54, "Subsection",ExpressionUUID->"90f2a486-7f2d-4578-b44f-0f4228b2d961"],
Cell[CellGroupData[{
Cell[1746, 59, 170, 3, 45, "Subsubsection",ExpressionUUID->"ed8a5825-031b-4e5c-803d-c935ac60f1ea"],
Cell[CellGroupData[{
Cell[1941, 66, 173, 3, 32, "Item",ExpressionUUID->"8cb018c9-3bd9-4cb2-8250-78e698f4bcb9"],
Cell[2117, 71, 186, 3, 32, "Item",ExpressionUUID->"b3c931dd-dd46-4542-a273-6422d0c2a00f"]
}, Open  ]],
Cell[2318, 77, 1359, 23, 280, "Input",ExpressionUUID->"5f498747-a4fc-4d75-9809-e24e6d13ccb1"],
Cell[3680, 102, 872, 16, 48, "Input",ExpressionUUID->"b9ba9e81-71ec-4d8f-810a-476a88cd5241"],
Cell[4555, 120, 229, 4, 28, "Input",ExpressionUUID->"dd2a7a59-73f0-48fc-af22-abaea0dd0700"],
Cell[4787, 126, 155, 3, 32, "Item",ExpressionUUID->"be04b616-f18e-485e-b1d2-100abfe30b16"],
Cell[4945, 131, 491, 13, 74, "Input",ExpressionUUID->"afe0f70b-f90e-4b43-9c18-4aabd6e8e58b"],
Cell[5439, 146, 152, 3, 32, "Item",ExpressionUUID->"e380db53-2322-4877-b3b0-326fc2a592ab"],
Cell[CellGroupData[{
Cell[5616, 153, 1333, 29, 31, "Input",ExpressionUUID->"d50cd050-68f2-4b2f-bd31-5074fd7d3cb8"],
Cell[6952, 184, 618, 9, 70, "Output",ExpressionUUID->"eb54d068-0fda-4fc4-bd99-020b819f3ace"]
}, Open  ]],
Cell[7585, 196, 557, 15, 45, "Input",ExpressionUUID->"29436073-fe15-4d7a-9273-261eccd83656"],
Cell[8145, 213, 1425, 40, 87, "Input",ExpressionUUID->"7040a96a-2c60-4dfa-ba22-f32459685d47"]
}, Closed]],
Cell[CellGroupData[{
Cell[9607, 258, 169, 3, 37, "Subsubsection",ExpressionUUID->"3a84fe44-9b09-4ef1-9e4e-bf76394012d4"],
Cell[9779, 263, 150, 3, 32, "Item",ExpressionUUID->"5185fa93-dcec-4550-bc58-078ffba46c3f"],
Cell[9932, 268, 2276, 65, 133, "Input",ExpressionUUID->"ff1e7daf-6115-42e2-8ab0-9df468c657f7"],
Cell[12211, 335, 159, 3, 32, "Item",ExpressionUUID->"d22a5d65-c959-4575-b2cd-95f33644d828"],
Cell[12373, 340, 2147, 57, 75, "Input",ExpressionUUID->"27e92e7b-b1bd-4e03-b6d4-9dae0177ca15"],
Cell[14523, 399, 2037, 60, 123, "Input",ExpressionUUID->"c84fb399-5b67-445d-8ea4-d6bae45c686c"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16609, 465, 556, 17, 54, "Subsection",ExpressionUUID->"7d855627-330f-409b-abdd-de23fa369931"],
Cell[17168, 484, 154, 3, 32, "Item",ExpressionUUID->"0bcff78e-d19b-49d0-a922-711c068b015c"],
Cell[17325, 489, 480, 14, 28, "Input",ExpressionUUID->"80c49d9a-d75b-4279-bbf4-f06368b12540"]
}, Closed]],
Cell[CellGroupData[{
Cell[17842, 508, 167, 3, 38, "Subsection",ExpressionUUID->"c19a04b2-cc25-403a-ac92-002bf533256f"],
Cell[18012, 513, 701, 17, 28, "Input",ExpressionUUID->"04069d94-15c6-41e6-8077-e27ae1b9dd02"],
Cell[CellGroupData[{
Cell[18738, 534, 231, 4, 32, "Item",ExpressionUUID->"8ba5f747-6b0c-4f75-9072-d1c5ae5b3033"],
Cell[18972, 540, 257, 4, 26, "Subitem",ExpressionUUID->"9ebb63ae-55dc-4a36-af23-e29096e205aa"]
}, Open  ]],
Cell[19244, 547, 1108, 26, 48, "Input",ExpressionUUID->"801f1fd9-96a0-48a9-9353-0cdbe2afc224"],
Cell[20355, 575, 158, 3, 32, "Item",ExpressionUUID->"731bbb0d-98f4-472e-86f5-56d9ecdbf8c9"],
Cell[20516, 580, 2005, 46, 260, "Input",ExpressionUUID->"7db7ee34-5e7a-49ef-81c2-251eea8bde4e"],
Cell[22524, 628, 407, 10, 28, "Input",ExpressionUUID->"5f38f525-4430-4406-8387-864539708326"],
Cell[22934, 640, 155, 3, 32, "Item",ExpressionUUID->"4b360739-ea39-45dd-a170-5ca80fe0f2f2"],
Cell[CellGroupData[{
Cell[23114, 647, 586, 11, 28, "Input",ExpressionUUID->"282d4b27-d671-4f5f-ace7-d96b8dbe3e12"],
Cell[23703, 660, 986, 18, 70, "Output",ExpressionUUID->"0053e624-c388-4677-8bcf-d16734c5119e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24738, 684, 249, 4, 38, "Subsection",ExpressionUUID->"3fe49e15-277d-4aec-af9e-42bcd817ce2f"],
Cell[CellGroupData[{
Cell[25012, 692, 225, 5, 32, "Item",ExpressionUUID->"fa1d3300-5b3c-4017-a29f-9fccb8292dec"],
Cell[CellGroupData[{
Cell[25262, 701, 280, 6, 26, "Subitem",ExpressionUUID->"d00e81d2-4d30-462f-b9f6-252e555c2349"],
Cell[25545, 709, 850, 26, 26, "Subitem",ExpressionUUID->"5aa31094-301c-43e6-952a-4a963ed3bbd2"],
Cell[26398, 737, 552, 16, 26, "Subitem",ExpressionUUID->"3d53cffa-a838-4083-9356-2b5adaf332fc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26999, 759, 759, 15, 45, "Subsubsection",ExpressionUUID->"adb26510-9b39-4af0-80bd-d3b77aecc9a9"],
Cell[27761, 776, 2726, 56, 87, "Input",ExpressionUUID->"e946f9cd-8c9f-4b5a-9359-80b44ccffdca"],
Cell[30490, 834, 2262, 58, 145, "Input",ExpressionUUID->"585cfd72-2d76-4fce-b60c-5b415942890e"]
}, Closed]],
Cell[CellGroupData[{
Cell[32789, 897, 777, 15, 37, "Subsubsection",ExpressionUUID->"2f31f6a6-16b6-4020-b1e5-0cfd73263479"],
Cell[33569, 914, 3811, 87, 134, "Input",ExpressionUUID->"b1d7b95b-4369-4e08-a287-ef178591a8fd"],
Cell[37383, 1003, 3280, 83, 145, "Input",ExpressionUUID->"63004bc8-ffef-401c-bc96-0a6dc2a989f1"]
}, Closed]],
Cell[CellGroupData[{
Cell[40700, 1091, 732, 19, 37, "Subsubsection",ExpressionUUID->"f70ec4be-3b86-4251-8d44-6976e479002e"],
Cell[41435, 1112, 2050, 49, 98, "Input",ExpressionUUID->"8c46c4bf-4a98-4009-b3f1-2397ad23efd2"]
}, Closed]],
Cell[CellGroupData[{
Cell[43522, 1166, 734, 19, 37, "Subsubsection",ExpressionUUID->"d4434744-1b9a-4226-a291-0554cb4ce22f"],
Cell[44259, 1187, 3535, 79, 122, "Input",ExpressionUUID->"759b1696-89ab-4de0-a246-ef559d3ab1ea"]
}, Closed]],
Cell[CellGroupData[{
Cell[47831, 1271, 813, 20, 37, "Subsubsection",ExpressionUUID->"49a41768-de80-486a-957b-2103045c7b30"],
Cell[48647, 1293, 7089, 184, 246, "Input",ExpressionUUID->"12c11dc4-1deb-4dc1-ae45-9be8f9cff30c"]
}, Closed]],
Cell[CellGroupData[{
Cell[55773, 1482, 466, 11, 37, "Subsubsection",ExpressionUUID->"9dd87468-c79e-49a3-a75a-87caaa896777"],
Cell[56242, 1495, 2680, 63, 114, "Input",ExpressionUUID->"6037cbae-a444-44d2-813d-36fc98e65f9f"]
}, Closed]],
Cell[CellGroupData[{
Cell[58959, 1563, 520, 12, 37, "Subsubsection",ExpressionUUID->"71b6aa65-053f-4e70-9fc0-cdfc5ab37e3a"],
Cell[59482, 1577, 4012, 104, 202, "Input",ExpressionUUID->"7ccf886d-c374-4911-928e-86b1d94d9993"]
}, Closed]],
Cell[CellGroupData[{
Cell[63531, 1686, 615, 14, 37, "Subsubsection",ExpressionUUID->"32a6d424-b70f-497f-8052-b78e5b055302"],
Cell[64149, 1702, 8646, 237, 394, "Input",ExpressionUUID->"5feb91e8-e4a9-4a7c-9d1f-a9efbb257759"]
}, Closed]],
Cell[CellGroupData[{
Cell[72832, 1944, 663, 15, 37, "Subsubsection",ExpressionUUID->"32ff115b-ba60-4190-b1ac-b9957f545375"],
Cell[73498, 1961, 4805, 135, 383, "Input",ExpressionUUID->"c469f2b9-b43d-4c75-b5ba-80c723680d40"]
}, Closed]],
Cell[CellGroupData[{
Cell[78340, 2101, 668, 15, 37, "Subsubsection",ExpressionUUID->"f9ea36f2-cec5-4872-8600-5aeb905db70e"],
Cell[79011, 2118, 4813, 110, 260, "Input",ExpressionUUID->"4ac54ca6-df78-4c2b-a94a-a70ab1adcb8e"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[83873, 2234, 217, 5, 54, "Subsection",ExpressionUUID->"94031006-f51b-4462-8f68-12b39bcf2d00"],
Cell[84093, 2241, 203, 4, 32, "Item",ExpressionUUID->"93b29dbf-06a0-4aa0-9223-b91f791db37d"],
Cell[84299, 2247, 1685, 38, 125, "Input",ExpressionUUID->"b9f5d905-c94f-4408-b289-db582b97f09a"],
Cell[85987, 2287, 177, 3, 32, "Item",ExpressionUUID->"e87b407e-3f1a-4e9f-89af-56c8d719dd85"],
Cell[86167, 2292, 1872, 39, 125, "Input",ExpressionUUID->"035b469f-ffe7-463d-9213-1ca54d4d0b62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88076, 2336, 274, 6, 54, "Subsection",ExpressionUUID->"843da4d7-aa30-46a2-b720-5c57128b1944"],
Cell[CellGroupData[{
Cell[88375, 2346, 367, 7, 32, "Item",ExpressionUUID->"84e987b5-6122-4701-be3d-8540e1acbc54"],
Cell[CellGroupData[{
Cell[88767, 2357, 445, 10, 26, "Subitem",ExpressionUUID->"1fb1b57c-86af-4310-8d93-52156b86a839"],
Cell[89215, 2369, 688, 13, 26, "Subitem",ExpressionUUID->"36979556-4616-4df4-a78a-82a88061617d"],
Cell[89906, 2384, 541, 10, 26, "Subitem",ExpressionUUID->"c9ef69a6-8e9b-4a32-9854-3630a4bc16de"],
Cell[90450, 2396, 486, 7, 25, "Subsubitem",ExpressionUUID->"b510c603-b184-427e-ba81-aa06601d300f"]
}, Open  ]],
Cell[90951, 2406, 176, 3, 32, "Item",ExpressionUUID->"edc63a24-279e-4170-accc-dbf1506dbc38"]
}, Open  ]],
Cell[91142, 2412, 1967, 40, 48, "Input",ExpressionUUID->"6405215b-34f3-4892-a767-482cca196e1b"],
Cell[93112, 2454, 731, 17, 28, "Input",ExpressionUUID->"4e51624e-3adc-4acd-ad57-9baa2992ed2f"],
Cell[CellGroupData[{
Cell[93868, 2475, 628, 19, 48, "Subsubsection",ExpressionUUID->"873be640-5e74-421c-ade7-a58df44baa67"],
Cell[94499, 2496, 445, 12, 45, "Input",ExpressionUUID->"0ea934a7-5c51-48a9-97eb-f88ef47da092"]
}, Closed]],
Cell[CellGroupData[{
Cell[94981, 2513, 411, 8, 63, "Subsubsection",ExpressionUUID->"7e051f07-8fbe-4bab-9703-2514b815a40b"],
Cell[CellGroupData[{
Cell[95417, 2525, 1243, 32, 123, "Input",ExpressionUUID->"405ab817-398f-4584-a795-8db8dd662190"],
Cell[96663, 2559, 1514, 35, 70, "Output",ExpressionUUID->"d9aff8e0-32c4-42af-a361-4ba978f677f2"]
}, Open  ]],
Cell[98192, 2597, 2175, 61, 104, "Input",ExpressionUUID->"3b7651ef-8ca6-4278-90e1-c5cf84747086"]
}, Closed]],
Cell[CellGroupData[{
Cell[100404, 2663, 601, 16, 37, "Subsubsection",ExpressionUUID->"859d714e-e4f0-4fd1-bee7-b4bfdf98d750"],
Cell[CellGroupData[{
Cell[101030, 2683, 370, 6, 28, "Input",ExpressionUUID->"4630b83f-86e7-46d6-81d4-fa19546cf523"],
Cell[101403, 2691, 1687, 35, 70, "Output",ExpressionUUID->"1a08952a-07d0-40af-950d-98b71694faeb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103127, 2731, 1080, 21, 31, "Input",ExpressionUUID->"fae41abb-e659-4019-b46e-dd12c74523c6"],
Cell[104210, 2754, 1556, 24, 70, "Output",ExpressionUUID->"755467cd-f2a3-4e7f-b479-a81a04b7942f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[105815, 2784, 244, 4, 37, "Subsubsection",ExpressionUUID->"a2c08c17-0f1c-481e-aea3-0a111740c769"],
Cell[CellGroupData[{
Cell[106084, 2792, 423, 10, 28, "Input",ExpressionUUID->"ac65dd78-9e5e-43c4-b3c7-fa6be879fd92"],
Cell[106510, 2804, 1616, 33, 70, "Output",ExpressionUUID->"55f79c0d-60dc-4e4c-921d-bd083f917c3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108163, 2842, 361, 9, 32, "Input",ExpressionUUID->"a5ef0625-6f0a-49e7-a588-655fbffd6f82"],
Cell[108527, 2853, 976, 16, 70, "Output",ExpressionUUID->"04b379dd-16da-4ef7-ae38-dc5b40dbd467"]
}, Open  ]],
Cell[109518, 2872, 585, 15, 33, "Item",ExpressionUUID->"92f2a714-98f2-4712-bd5d-5e46d212b3f3"],
Cell[CellGroupData[{
Cell[110128, 2891, 377, 9, 28, "Input",ExpressionUUID->"937e7131-de8d-425f-b5d1-4b17a03e30e6"],
Cell[110508, 2902, 1173, 21, 70, "Output",ExpressionUUID->"5bb1a5b1-4b37-4103-8579-2046ee86c683"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111718, 2928, 1418, 41, 61, "Input",ExpressionUUID->"c8202ecc-c906-4c00-9a01-7a14f9b035f4"],
Cell[113139, 2971, 2218, 55, 70, "Output",ExpressionUUID->"584c90fc-7701-4ad3-afa9-c5974d8621ca"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[115406, 3032, 228, 4, 37, "Subsubsection",ExpressionUUID->"447cfd8b-94a0-45ab-ae9c-884f34325272"],
Cell[115637, 3038, 176, 3, 32, "Item",ExpressionUUID->"fcdb0f9c-1449-44d8-815f-bf0746130a79"],
Cell[115816, 3043, 349, 9, 28, "Input",ExpressionUUID->"4b392941-d5f9-4c4c-b3b4-cbc98d5a960e"],
Cell[116168, 3054, 436, 11, 32, "Item",ExpressionUUID->"bd31b240-1492-4a9b-83d1-dacdbbf625da"],
Cell[116607, 3067, 2187, 62, 75, "Input",ExpressionUUID->"78af7975-0511-4fa3-b046-116daaca9977"],
Cell[118797, 3131, 237, 6, 32, "Item",ExpressionUUID->"84ac635d-352b-433f-8710-08e709740d8a"],
Cell[CellGroupData[{
Cell[119059, 3141, 723, 17, 28, "Input",ExpressionUUID->"f71cf21d-1d21-456f-9add-4e8f111e121e"],
Cell[119785, 3160, 5999, 164, 70, "Output",ExpressionUUID->"e68056d1-57b7-41c0-bf12-5d736b7874f3"]
}, Open  ]],
Cell[125799, 3327, 298, 7, 31, "Item",ExpressionUUID->"ac842bc1-df0f-432c-a6a5-4b7a361138e5"],
Cell[CellGroupData[{
Cell[126122, 3338, 369, 9, 28, "Input",ExpressionUUID->"56163384-6eac-4a00-b93d-63623094a8bf"],
Cell[126494, 3349, 5280, 142, 70, "Output",ExpressionUUID->"58242057-f749-494e-b4ce-ef451a995d83"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131811, 3496, 325, 6, 28, "Input",ExpressionUUID->"0a2b9ae8-5188-41f8-a937-846b34d6be75"],
Cell[132139, 3504, 2947, 81, 70, "Output",ExpressionUUID->"dd3cd041-e5eb-4570-b282-a2a5c9302de2"]
}, Open  ]],
Cell[135101, 3588, 564, 16, 28, "Input",ExpressionUUID->"e956700d-f608-41a9-943a-f1e7f500e279"],
Cell[135668, 3606, 446, 11, 51, "Item",ExpressionUUID->"8e600f6a-c0ca-485d-9414-80dfe0edc752"],
Cell[CellGroupData[{
Cell[136139, 3621, 947, 26, 28, "Input",ExpressionUUID->"4b38a561-558e-442c-bfd4-d2bd7d8ed5b4"],
Cell[137089, 3649, 995, 22, 70, "Output",ExpressionUUID->"46cc565e-3aa4-4006-9211-8875a7b0e5f1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[138133, 3677, 334, 10, 38, "Subsubsection",ExpressionUUID->"fae3c7eb-8da2-4d3c-b894-58beeeecfe68"],
Cell[138470, 3689, 217, 4, 32, "Item",ExpressionUUID->"477bf317-241b-4b52-8ba6-64c15746627d"],
Cell[CellGroupData[{
Cell[138712, 3697, 1793, 40, 106, "Input",ExpressionUUID->"8e6d4d58-9a29-476b-b60f-2e8e5b9076da"],
Cell[140508, 3739, 801, 12, 32, "Output",ExpressionUUID->"976a01a2-9d4a-4796-ac3d-43e556a70509"],
Cell[141312, 3753, 801, 12, 32, "Output",ExpressionUUID->"0f7a4cd3-3fb6-4c1f-8ae1-f6ecf61fac18"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[142174, 3772, 180, 3, 67, "Section",ExpressionUUID->"c6b79117-9a7b-43f6-ab6a-91952681c54b"],
Cell[142357, 3777, 701, 19, 58, "Text",ExpressionUUID->"1f605d4a-c156-4b43-8b86-6a4392569ed8"]
}, Open  ]]
}, Open  ]]
}
]
*)

